@@ -6,15 +6,14 @@
  * Date        : 2013-03-02
  * Description : Table view: Column cpp dialog
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMN_CONFIGURATION_DIALOG_H
-#define DIGIKAM_TABLE_VIEW_COLUMN_CONFIGURATION_DIALOG_H
+#pragma once
 
 // KDE includes
 
@@ -40,7 +39,7 @@ public:
     explicit TableViewConfigurationDialog(TableViewShared* const sharedObject,
                                           const int columnIndex,
                                           QWidget* const parentWidget);
-    ~TableViewConfigurationDialog() override;
+    ~TableViewConfigurationDialog()                          override;
 
     TableViewColumnConfiguration getNewConfiguration() const;
 
@@ -49,9 +48,7 @@ private:
     class Private;
 
     const QScopedPointer<Private> d;
-    TableViewShared* const        s;
+    TableViewShared* const        s = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMN_CONFIGURATION_DIALOG_H
