@@ -6,14 +6,13 @@
  * Date        : 2015-07-18
  * Description : DNG Raw Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2015-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_DNG_H
-#define DIGIKAM_BQM_CONVERT_TO_DNG_H
+#pragma once
 
 // Local includes
 
@@ -33,7 +32,7 @@ class ConvertToDNG : public BatchTool
 public:
 
     explicit ConvertToDNG(QObject* const parent = nullptr);
-    ~ConvertToDNG() override;
+    ~ConvertToDNG()                                         override = default;
 
     void cancel()                                           override;
     QString outputSuffix()                            const override;
@@ -56,9 +55,7 @@ private:
 private:
 
     DNGWriter m_dngProcessor;
-    bool      m_changeSettings;
+    bool      m_changeSettings  = true;
 };
 
 } // namespace DigikamBqmConvertToDngPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_DNG_H
