@@ -6,15 +6,14 @@
  * Date        : 2014-05-24
  * Description : user script batch tool.
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Hubert Law <hhclaw dot eb at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_USER_SCRIPT_H
-#define DIGIKAM_BQM_USER_SCRIPT_H
+#pragma once
 
 // Local includes
 
@@ -54,9 +53,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamBqmUserScriptPlugin
-
-#endif // DIGIKAM_BQM_USER_SCRIPT_H
