@@ -6,14 +6,13 @@
  * Date        : 2010-03-15
  * Description : Anti-vignetting batch tool.
  *
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_ANTI_VIGNETTING_H
-#define DIGIKAM_BQM_ANTI_VIGNETTING_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ class AntiVignetting : public BatchTool
 public:
 
     explicit AntiVignetting(QObject* const parent = nullptr);
-    ~AntiVignetting()                                       override;
+    ~AntiVignetting()                                       override = default;
 
     BatchToolSettings defaultSettings()                     override;
 
@@ -51,9 +50,7 @@ private Q_SLOTS:
 
 private:
 
-    AntiVignettingSettings* m_settingsView;
+    AntiVignettingSettings* m_settingsView = nullptr;
 };
 
 } // namespace DigikamBqmAntiVignettingPlugin
-
-#endif // DIGIKAM_BQM_ANTI_VIGNETTING_H
