@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to reduce lens artifacts
  *
- * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_LENS_AUTO_FIX_PLUGIN_H
-#define DIGIKAM_LENS_AUTO_FIX_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class LensAutoFixPlugin : public DPluginBqm
 public:
 
     explicit LensAutoFixPlugin(QObject* const parent = nullptr);
-    ~LensAutoFixPlugin()                 override;
+    ~LensAutoFixPlugin()                 override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmLensAutoFixPlugin
-
-#endif // DIGIKAM_LENS_AUTO_FIX_PLUGIN_H
