@@ -7,7 +7,7 @@
  * Description : a tool to export GPS data to KML file.
  *
  * SPDX-FileCopyrightText: 2006-2007 by Stephane Pontier <shadow dot walker at free dot fr>
- * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -41,20 +41,8 @@ namespace DigikamGenericGeolocationEditPlugin
 {
 
 KmlExport::KmlExport(DInfoInterface* const iface)
-    : m_localTarget       (true),
-      m_optimize_googlemap(false),
-      m_GPXtracks         (false),
-      m_iconSize          (33),
-      m_googlemapSize     (32),
-      m_size              (320),
-      m_altitudeMode      (0),
-      m_TimeZone          (12),
-      m_LineWidth         (4),
-      m_GPXOpacity        (64),
-      m_GPXAltitudeMode   (0),
-      m_iface             (iface),
-      m_meta              (new DMetadata),
-      m_kmlDocument       (nullptr)
+    : m_iface(iface),
+      m_meta (new DMetadata)
 {
 }
 
@@ -115,13 +103,13 @@ QImage KmlExport::generateBorderedThumbnail(const QImage& fullImage, int size) c
 
     // getting an image minus the border
 
-    QImage image     = fullImage.scaled(size -(2*image_border), size - (2*image_border), Qt::KeepAspectRatioByExpanding);
+    QImage image     = fullImage.scaled(size -(2 * image_border), size - (2 * image_border), Qt::KeepAspectRatioByExpanding);
 
-    QPixmap croppedPix(image.width() + (2*image_border), image.height() + (2*image_border));
+    QPixmap croppedPix(image.width() + (2 * image_border), image.height() + (2 * image_border));
     QPainter painter(&croppedPix);
 
     QColor BrushColor(255, 255, 255);
-    painter.fillRect(0, 0, image.width() + (2*image_border),image.height() + (2*image_border), BrushColor);
+    painter.fillRect(0, 0, image.width() + (2 * image_border),image.height() + (2 * image_border), BrushColor);
 
     /*! @todo add a corner to the thumbnail and a hotspot to the kml element */
 
@@ -318,7 +306,7 @@ void KmlExport::generateImagesthumb(const QUrl& imageURL, QDomElement& kmlAlbum)
             my_description = QLatin1String("<img src=\"") + m_imageDirBasename + QLatin1Char('/') + fullFileName + QLatin1String("\">");
         }
 
-        my_description += QLatin1String("<br/>") + info.comment() ;
+        my_description += QLatin1String("<br>") + info.comment() ;
 
         addKmlTextElement(kmlPlacemark, QLatin1String("description"), my_description);
         logInfo(i18n("Creation of placemark '%1'", fullFileName));
@@ -549,7 +537,7 @@ bool KmlExport::copyDir(const QString& srcFilePath, const QString& dstFilePath)
 
         QStringList files = srcDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
 
-        Q_FOREACH (const QString& file, files)
+        for (const QString& file : std::as_const(files))
         {
             const QString newSrcFilePath = srcDir.absolutePath() + QLatin1Char('/') + file;
             const QString newDstFilePath = dstDir.absolutePath() + QLatin1Char('/') + file;
