@@ -6,14 +6,13 @@
  * Date        : 2017-06-27
  * Description : a tool to create calendar.
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CAL_INTRO_PAGE_H
-#define DIGIKAM_CAL_INTRO_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -35,9 +34,7 @@ class CalIntroPage : public DWizardPage
 public:
 
     explicit CalIntroPage(QWizard* const dialog, const QString& title);
-    ~CalIntroPage() override;
+    ~CalIntroPage() override = default;
 };
 
 } // namespace DigikamGenericCalendarPlugin
-
-#endif // DIGIKAM_CAL_INTRO_PAGE_H
