@@ -6,14 +6,13 @@
  * Date        : 2012-05-28
  * Description : Media Server configuration dialog to share a single list of files
  *
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DMEDIA_SERVER_DLG_H
-#define DIGIKAM_DMEDIA_SERVER_DLG_H
+#pragma once
 
 // Qt includes
 
@@ -61,9 +60,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericMediaServerPlugin
-
-#endif // DIGIKAM_DMEDIA_SERVER_DLG_H
