@@ -6,7 +6,7 @@
  * Date        : 2022-08-26
  * Description : Text converter batch dialog
  *
- * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2022      by Quoc Hung Tran <quochungtran1999 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -55,7 +55,7 @@ using namespace Digikam;
 namespace DigikamGenericTextConverterPlugin
 {
 
-class TextConverterDialog::Private
+class Q_DECL_HIDDEN TextConverterDialog::Private
 {
 public:
 
@@ -73,47 +73,36 @@ public:
 
 public:
 
-    Private()
-      : busy                (false),
-        progressBar         (nullptr),
-        thread              (nullptr),
-        iface               (nullptr),
-        listView            (nullptr),
-        ocrSettings         (nullptr),
-        textedit            (nullptr),
-        saveTextButton      (nullptr),
-        currentSelectedItem (nullptr),
-        binWidget           (nullptr),
-        tabView             (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                              busy;
+public:
+
+    bool                              busy                  = false;
 
     QList<QUrl>                       fileList;
 
     QMap<QUrl, QString>               textEditList;
 
-    DProgressWdg*                     progressBar;
+    DProgressWdg*                     progressBar           = nullptr;
 
-    TextConverterActionThread*        thread;
+    TextConverterActionThread*        thread                = nullptr;
 
-    DInfoInterface*                   iface;
+    DInfoInterface*                   iface                 = nullptr;
 
-    TextConverterList*                listView;
+    TextConverterList*                listView              = nullptr;
 
-    TextConverterSettings*            ocrSettings;
+    TextConverterSettings*            ocrSettings           = nullptr;
 
-    DTextEdit*                        textedit;
+    DTextEdit*                        textedit              = nullptr;
 
-    QPushButton*                      saveTextButton;
+    QPushButton*                      saveTextButton        = nullptr;
 
-    TextConverterListViewItem*        currentSelectedItem;
+    TextConverterListViewItem*        currentSelectedItem   = nullptr;
 
     TesseractBinary                   tesseractBin;
-    DBinarySearch*                    binWidget;
+    DBinarySearch*                    binWidget             = nullptr;
 
-    QTabWidget*                       tabView;
+    QTabWidget*                       tabView               = nullptr;
 };
 
 TextConverterDialog::TextConverterDialog(QWidget* const parent, DInfoInterface* const iface)
@@ -124,9 +113,7 @@ TextConverterDialog::TextConverterDialog(QWidget* const parent, DInfoInterface*
     setModal(true);
 
     d->iface          = iface;
-
-    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing = layoutSpacing();
 
     m_buttons->addButton(QDialogButtonBox::Close);
     m_buttons->addButton(QDialogButtonBox::Ok);
@@ -162,7 +149,7 @@ TextConverterDialog::TextConverterDialog(QWidget* const parent, DInfoInterface*
 
     QScrollArea* const recsv      = new QScrollArea(d->tabView);
     DVBox* const recognitionTab   = new DVBox(recsv->viewport());
-    QLabel* const tesseractLabel  = new QLabel(i18nc("@label", "This tool use the %1 open-source "
+    QLabel* const tesseractLabel  = new QLabel(i18nc("@label", "This tool uses the %1 open-source "
                                                "engine to perform Optical Characters Recognition. "
                                                "Tesseract program and the desired languages modules must "
                                                "be installed on your system.",
@@ -216,7 +203,7 @@ TextConverterDialog::TextConverterDialog(QWidget* const parent, DInfoInterface*
 
     DVBox* const reviewTab = new DVBox(d->tabView);
     d->textedit            = new DTextEdit(0, reviewTab);
-    d->textedit->setPlaceholderText(i18nc("@info", "After to process recognition, "
+    d->textedit->setPlaceholderText(i18nc("@info", "After processing recognition, "
                                                    "double-click on one item to "
                                                    "display recognized text here. "
                                                    "You can review words and fix "
@@ -668,7 +655,7 @@ void TextConverterDialog::setBusy(bool busy)
     else
     {
         m_buttons->button(QDialogButtonBox::Ok)->setText(i18nc("@action", "&Start OCR"));
-        m_buttons->button(QDialogButtonBox::Ok)->setToolTip(i18nc("@info", "Start OCR using the current settings."));      
+        m_buttons->button(QDialogButtonBox::Ok)->setToolTip(i18nc("@info", "Start OCR using the current settings."));
         plugProcessMenu();
     }
 
