@@ -6,7 +6,7 @@
  * Date        : 2017-06-27
  * Description : a tool to export items by email.
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -139,10 +139,10 @@ void MailFinalPage::slotProcess()
                                   DHistoryView::ProgressEntry);
     }
 
-
     d->progressBar->setMinimum(0);
     d->progressBar->setMaximum(d->settings->itemsList.count());
 
+    delete d->processor;
     d->processor = new MailProcess(d->settings, d->iface, this);
 
     connect(d->processor, SIGNAL(signalProgress(int)),
@@ -151,7 +151,7 @@ void MailFinalPage::slotProcess()
     connect(d->processor, SIGNAL(signalMessage(QString,bool)),
             this, SLOT(slotMessage(QString,bool)));
 
-    connect(d->processor, SIGNAL(signalDone(bool)),
+    connect(d->processor, SIGNAL(signalComplete(bool)),
             this, SLOT(slotDone()));
 
     d->processor->firstStage();
