@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : plugin to create video slideshow.
  *
- * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_VIDEO_SLIDESHOW_PLUGIN_H
-#define DIGIKAM_VIDEO_SLIDESHOW_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -26,6 +25,8 @@ using namespace Digikam;
 namespace DigikamGenericVideoSlideShowPlugin
 {
 
+class VidSlideWizard;
+
 class VideoSlideShowPlugin : public DPluginGeneric
 {
     Q_OBJECT
@@ -35,7 +36,7 @@ class VideoSlideShowPlugin : public DPluginGeneric
 public:
 
     explicit VideoSlideShowPlugin(QObject* const parent = nullptr);
-    ~VideoSlideShowPlugin()              override;
+    ~VideoSlideShowPlugin()              override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -47,12 +48,15 @@ public:
     QString handbookChapter()      const override;
 
     void setup(QObject* const) override;
+    void cleanUp()                       override;
 
 private Q_SLOTS:
 
     void slotVideoSlideShow();
+
+private:
+
+    QPointer<VidSlideWizard> m_toolDlg;
 };
 
 } // namespace DigikamGenericVideoSlideShowPlugin
-
-#endif // DIGIKAM_VIDEO_SLIDESHOW_PLUGIN_H
