@@ -7,7 +7,7 @@
  * Description : a presentation tool.
  *
  * SPDX-FileCopyrightText: 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -24,10 +24,9 @@
 
 // Local includes
 
+#include "digikam_debug.h"
 #include "presentation_mainpage.h"
 #include "presentationcontainer.h"
-#include "digikam_debug.h"
-#include "digikam_globals.h"
 #include "dfiledialog.h"
 
 using namespace Digikam;
@@ -55,10 +54,6 @@ SoundtrackPreview::SoundtrackPreview(QWidget* const parent,
     setLayout(layout);
 }
 
-SoundtrackPreview::~SoundtrackPreview()
-{
-}
-
 // ------------------------------------------------------------------------------------
 
 class Q_DECL_HIDDEN PresentationAudioPage::Private
@@ -67,6 +62,8 @@ public:
 
     Private() = default;
 
+public:
+
     QList<QUrl>                             urlList;
     PresentationContainer*                  sharedData = nullptr;
     QTime                                   totalTime;
@@ -432,7 +429,7 @@ void PresentationAudioPage::slotSoundFilesButtonUp()
 
     PresentationAudioListItem* const pitem = static_cast<PresentationAudioListItem*>(m_SoundFilesListBox->takeItem(index));
 
-    m_SoundFilesListBox->insertItem(index - 1, pitem);
+    m_SoundFilesListBox->insertItem(((index > 0) ? index - 1 : index), pitem);
     m_SoundFilesListBox->setCurrentItem(pitem);
 
     updateFileList();
@@ -491,7 +488,7 @@ void PresentationAudioPage::slotSoundFilesButtonLoad()
         return;
     }
 
-    QString filename = dlg->selectedFiles().first();
+    QString filename = dlg->selectedFiles().constFirst();
 
     if (!filename.isEmpty())
     {
@@ -550,7 +547,7 @@ void PresentationAudioPage::slotSoundFilesButtonSave()
         return;
     }
 
-    QString filename = dlg->selectedFiles().first();
+    QString filename = dlg->selectedFiles().constFirst();
 
     if (!filename.isEmpty())
     {
@@ -567,7 +564,7 @@ void PresentationAudioPage::slotSoundFilesButtonSave()
 
                 if (fUrl.isValid() && fUrl.isLocalFile())
                 {
-                    out << fUrl.toLocalFile() << QT_ENDL;
+                    out << fUrl.toLocalFile() << Qt::endl;
                 }
             }
 
