@@ -61,7 +61,7 @@ QString BoxPlugin::description() const
 
 QString BoxPlugin::details() const
 {
-    return i18nc("@info", "This tool allows users to export items to Box web-service.\n\n"
+    return i18nc("@info", "This tool allows users to export items to Box web-service.<br><br>"
                 "See Box web site for details: %1", QLatin1String("<a href='https://box.com/'>https://box.com/</a>"));
 }
 
