@@ -58,35 +58,25 @@ class Q_DECL_HIDDEN GSWindow::Private
 {
 public:
 
-    explicit Private()
-      : imagesCount   (0),
-        imagesTotal   (0),
-        renamingOpt   (0),
-        service       (GoogleService::GPhotoImport),
-        widget        (nullptr),
-        albumDlg      (nullptr),
-        gphotoAlbumDlg(nullptr),
-        talker        (nullptr),
-        gphotoTalker  (nullptr),
-        iface         (nullptr)
-    {
-    }
+    Private() = default;
 
-    unsigned int                  imagesCount;
-    unsigned int                  imagesTotal;
-    int                           renamingOpt;
+public:
+
+    unsigned int                  imagesCount       = 0;
+    unsigned int                  imagesTotal       = 0;
+    int                           renamingOpt       = 0;
 
     QString                       serviceName;
     QString                       toolName;
-    GoogleService                 service;
+    GoogleService                 service           = GoogleService::GPhotoImport;
     QString                       tmp;
 
-    GSWidget*                     widget;
-    GSNewAlbumDlg*                albumDlg;
-    GSNewAlbumDlg*                gphotoAlbumDlg;
+    GSWidget*                     widget            = nullptr;
+    GSNewAlbumDlg*                albumDlg          = nullptr;
+    GSNewAlbumDlg*                gphotoAlbumDlg    = nullptr;
 
-    GDTalker*                     talker;
-    GPTalker*                     gphotoTalker;
+    GDTalker*                     talker            = nullptr;
+    GPTalker*                     gphotoTalker      = nullptr;
 
     QString                       currentAlbumId;
     QString                       newFolderTitle;
@@ -94,7 +84,7 @@ public:
     QList< QPair<QUrl, GSPhoto> > transferQueue;
     QList< QPair<QUrl, GSPhoto> > uploadQueue;
 
-    DInfoInterface*               iface;
+    DInfoInterface*               iface             = nullptr;
 };
 
 GSWindow::GSWindow(DInfoInterface* const iface,
@@ -281,12 +271,16 @@ void GSWindow::readSettings()
     switch (d->service)
     {
         case GoogleService::GDrive:
+        {
             grp = config->group(QLatin1String("Google Drive Settings"));
             break;
+        }
 
         default:
+        {
             grp = config->group(QLatin1String("Google Photo Settings"));
             break;
+        }
     }
 
     d->currentAlbumId = grp.readEntry("Current Album", QString());
@@ -321,12 +315,16 @@ void GSWindow::writeSettings()
     switch (d->service)
     {
         case GoogleService::GDrive:
+        {
             grp = config->group(QLatin1String("Google Drive Settings"));
             break;
+        }
 
         default:
+        {
             grp = config->group(QLatin1String("Google Photo Settings"));
             break;
+        }
     }
 
     grp.writeEntry("Current Album",   d->currentAlbumId);
@@ -496,7 +494,7 @@ void GSWindow::slotStartTransfer()
         {
             if (d->widget->imagesList()->imageUrls().isEmpty())
             {
-                QMessageBox::critical(this, i18nc("@title:window", "Error"),
+                QMessageBox::critical(this, i18nc("@title: window start transfer", "Error"),
                                       i18nc("@info", "No image selected. Please select which images should be uploaded."));
                 return;
             }
@@ -505,7 +503,9 @@ void GSWindow::slotStartTransfer()
         }
 
         case GoogleService::GPhotoImport:
+        {
             break;
+        }
     }
 
     switch (d->service)
@@ -515,12 +515,12 @@ void GSWindow::slotStartTransfer()
             if (!(d->talker->authenticated()))
             {
                 QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                 i18nc("@title:window", "Warning"),
+                                 i18nc("@title: window start transfer", "Warning"),
                                  i18nc("@info", "Authentication failed. Click \"Continue\" to authenticate."),
                                  QMessageBox::Yes | QMessageBox::No);
 
-                (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-                (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+                (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button start transfer", "Continue"));
+                (warn->button(QMessageBox::No))->setText(i18nc("@action: button start transfer", "Cancel"));
 
                 if (warn->exec() == QMessageBox::Yes)
                 {
@@ -545,12 +545,12 @@ void GSWindow::slotStartTransfer()
             if (!(d->gphotoTalker->authenticated()))
             {
                 QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                 i18nc("@title:window", "Warning"),
+                                 i18nc("@title: window start transfer", "Warning"),
                                  i18nc("@info", "Authentication failed. Click \"Continue\" to authenticate."),
                                  QMessageBox::Yes | QMessageBox::No);
 
-                (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-                (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+                (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button start transfer", "Continue"));
+                (warn->button(QMessageBox::No))->setText(i18nc("@action: button start transfer", "Cancel"));
 
                 if (warn->exec() == QMessageBox::Yes)
                 {
@@ -567,7 +567,7 @@ void GSWindow::slotStartTransfer()
 
             if (d->service == GoogleService::GPhotoImport)
             {
-                qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Google Photo Transfer invoked";
+                qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Google Photos Transfer invoked";
 
                 // list photos of the album, then start download
 
@@ -593,11 +593,14 @@ void GSWindow::slotStartTransfer()
         switch (d->service)
         {
             case GoogleService::GDrive:
+            {
                 temp.title       = info.title();
                 temp.description = info.comment().section(QLatin1String("\n"), 0, 0);
                 break;
+            }
 
             default:
+            {
                 temp.title = info.name();
 
                 // Google Photo doesn't support image titles. Include it in descriptions if needed.
@@ -614,6 +617,7 @@ void GSWindow::slotStartTransfer()
                 temp.description.replace(QLatin1Char('"'), QLatin1String("\\\""));
                 temp.description         = temp.description.left(1000);
                 break;
+            }
         }
 
         temp.gpsLat.setNum(info.latitude());
@@ -627,7 +631,7 @@ void GSWindow::slotStartTransfer()
     d->imagesTotal    = d->transferQueue.count();
     d->imagesCount    = 0;
 
-    d->widget->progressBar()->setFormat(i18nc("@info: progress bar", "%v / %m"));
+    d->widget->progressBar()->setFormat(i18nc("@info: progress bar start transfer", "%v / %m"));
     d->widget->progressBar()->setMaximum(d->imagesTotal);
     d->widget->progressBar()->setValue(0);
     d->widget->progressBar()->show();
@@ -635,16 +639,20 @@ void GSWindow::slotStartTransfer()
     switch (d->service)
     {
         case GoogleService::GDrive:
-            d->widget->progressBar()->progressScheduled(i18nc("@info", "Google Drive export"), true, true);
+        {
+            d->widget->progressBar()->progressScheduled(i18nc("@info: start transfer", "Google Drive export"), true, true);
             d->widget->progressBar()->progressThumbnailChanged(
                 QIcon::fromTheme(QLatin1String("dk-googledrive")).pixmap(22, 22));
             break;
+        }
 
         default:
-            d->widget->progressBar()->progressScheduled(i18nc("@info", "Google Photo export"), true, true);
+        {
+            d->widget->progressBar()->progressScheduled(i18nc("@info: start transfer", "Google Photos export"), true, true);
             d->widget->progressBar()->progressThumbnailChanged(
                 QIcon::fromTheme((QLatin1String("dk-googlephoto"))).pixmap(22, 22));
             break;
+        }
     }
 
     uploadNextPhoto();
@@ -707,12 +715,16 @@ void GSWindow::uploadNextPhoto()
                 switch (d->renamingOpt)
                 {
                     case PWR_ADD_ALL:
+                    {
                         bAdd = true;
                         break;
+                    }
 
                     case PWR_REPLACE_ALL:
+                    {
                         bAdd = false;
                         break;
+                    }
 
                     default:
                     {
@@ -724,25 +736,35 @@ void GSWindow::uploadNextPhoto()
                         switch (dlg->getResult())
                         {
                             case PWR_ADD_ALL:
+                            {
                                 d->renamingOpt = PWR_ADD_ALL;
                                 break;
+                            }
 
                             case PWR_ADD:
+                            {
                                 bAdd = true;
                                 break;
+                            }
 
                             case PWR_REPLACE_ALL:
+                            {
                                 d->renamingOpt = PWR_REPLACE_ALL;
                                 break;
+                            }
 
                             case PWR_REPLACE:
+                            {
                                 bAdd = false;
                                 break;
+                            }
 
                             case PWR_CANCEL:
                             default:
+                            {
                                 bCancel = true;
                                 break;
+                            }
                         }
 
                         delete dlg;
@@ -847,7 +869,9 @@ void GSWindow::uploadNextPhoto()
         }
 
         case GoogleService::GPhotoImport:
+        {
             break;
+        }
     }
 
     if (!res)
@@ -959,13 +983,13 @@ void GSWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
         else
         {
             QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                             i18nc("@title:window", "Warning"),
+                             i18nc("@title: window get photo done", "Warning"),
                              i18nc("@info", "Failed to save photo: %1\n"
                                    "Do you want to continue?", errText),
                              QMessageBox::Yes | QMessageBox::No);
 
-            (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-            (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+            (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button get photo done", "Continue"));
+            (warn->button(QMessageBox::No))->setText(i18nc("@action: button get photo done", "Cancel"));
 
             if (warn->exec() != QMessageBox::Yes)
             {
@@ -980,13 +1004,13 @@ void GSWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
     else
     {
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                         i18nc("@title:window", "Warning"),
+                         i18nc("@title: window get photo done", "Warning"),
                          i18nc("@info", "Failed to download photo: %1\n"
                               "Do you want to continue?", errMsg),
                          QMessageBox::Yes | QMessageBox::No);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-        (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button get photo done", "Continue"));
+        (warn->button(QMessageBox::No))->setText(i18nc("@action: button get photo done", "Cancel"));
 
         if (warn->exec() != QMessageBox::Yes)
         {
@@ -1007,12 +1031,13 @@ void GSWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
 
     if (!QFile::rename(tmpUrl.toLocalFile(), newUrl.toLocalFile()))
     {
-        QMessageBox::critical(this, i18nc("@title:window", "Error"),
+        QMessageBox::critical(this, i18nc("@title: window get photo done", "Error"),
                               i18nc("@info", "Failed to save image to %1",
                                    newUrl.toLocalFile()));
     }
 
     Q_EMIT updateHostApp(newUrl);
+
     downloadNextPhoto();
 }
 
@@ -1028,14 +1053,14 @@ void GSWindow::slotAddPhotoDone(int err, const QString& msg)
         d->widget->imagesList()->processed(d->transferQueue.first().first,false);
 
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                         i18nc("@title:window", "Warning"),
+                         i18nc("@title: window add photo done", "Warning"),
                          i18nc("@info", "Failed to upload photo to %1.\n%2\n"
                               "Do you want to continue?",
                               d->toolName, msg),
                          QMessageBox::Yes | QMessageBox::No);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-        (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button add photo done", "Continue"));
+        (warn->button(QMessageBox::No))->setText(i18nc("@action: button add photo done", "Cancel"));
 
         if (warn->exec() != QMessageBox::Yes)
         {
@@ -1078,13 +1103,13 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
     if (err == 0)
     {
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                                     i18nc("@title:window", "Warning"),
+                                                     i18nc("@title: window upload photo done", "Warning"),
                                                      i18nc("@info", "Failed to finish uploading photo to %1.\n%2\n"
                                                            "No image uploaded to your account.",
                                                            d->toolName, msg),
                                                      QMessageBox::Yes);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "OK"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button upload photo done", "OK"));
 
         d->uploadQueue.clear();
         d->widget->progressBar()->hide();
@@ -1093,7 +1118,7 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
     }
     else
     {
-        Q_FOREACH (const QString& photoId, listPhotoId)
+        for (const QString& photoId : std::as_const(listPhotoId))
         {
             // Remove image from upload list and from UI
 
@@ -1106,11 +1131,13 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
 
             QScopedPointer<DMetadata> meta(new DMetadata);
 
-            if (d->widget->getPhotoIdCheckBox()->isChecked() &&
+            if (
+                d->widget->getPhotoIdCheckBox()->isChecked() &&
                 meta->supportXmp()                           &&
                 meta->canWriteXmp(fileUrl.toLocalFile())     &&
                 meta->load(fileUrl.toLocalFile())            &&
-                !photoId.isEmpty())
+                !photoId.isEmpty()
+               )
             {
                 meta->setXmpTagString("Xmp.digiKam.picasawebGPhotoId", photoId);
                 meta->save(fileUrl.toLocalFile());
@@ -1120,6 +1147,7 @@ void GSWindow::slotUploadPhotoDone(int err, const QString& msg, const QStringLis
         if (!d->widget->imagesList()->imageUrls().isEmpty())
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "continue to upload";
+
             Q_EMIT d->gphotoTalker->signalReadyToUpload();
         }
     }
@@ -1177,13 +1205,17 @@ void GSWindow::slotReloadAlbumsRequest()
     switch (d->service)
     {
         case GoogleService::GDrive:
+        {
             d->talker->listFolders();
             break;
+        }
 
         case GoogleService::GPhotoImport:
         case GoogleService::GPhotoExport:
+        {
             d->gphotoTalker->listAlbums();
             break;
+        }
     }
 }
 
@@ -1192,13 +1224,17 @@ void GSWindow::slotAccessTokenObtained()
     switch (d->service)
     {
         case GoogleService::GDrive:
+        {
             d->talker->listFolders();
             break;
+        }
 
         case GoogleService::GPhotoImport:
         case GoogleService::GPhotoExport:
+        {
             d->gphotoTalker->getLoggedInUser();
             break;
+        }
     }
 }
 
@@ -1226,7 +1262,7 @@ void GSWindow::slotCreateFolderDone(int code, const QString& msg, const QString&
         {
             if (code == 0)
             {
-                QMessageBox::critical(this, i18nc("@title:window", "Error"),
+                QMessageBox::critical(this, i18nc("@title: window create folder", "Error"),
                                       i18nc("@info", "Google Drive call failed:\n%1", msg));
             }
             else
@@ -1243,7 +1279,7 @@ void GSWindow::slotCreateFolderDone(int code, const QString& msg, const QString&
         {
             if (code == 0)
             {
-                QMessageBox::critical(this, i18nc("@title:window", "Error"),
+                QMessageBox::critical(this, i18nc("@title: window create folder", "Error"),
                                       i18nc("@info", "Google Photos call failed:\n%1", msg));
             }
             else
@@ -1268,26 +1304,30 @@ void GSWindow::slotTransferCancel()
     switch (d->service)
     {
         case GoogleService::GDrive:
+        {
             d->talker->cancel();
             break;
+        }
 
         case GoogleService::GPhotoImport:
         case GoogleService::GPhotoExport:
+        {
             d->gphotoTalker->cancel();
             break;
+        }
     }
 }
 
 void GSWindow::slotUserChangeRequest()
 {
     QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                                                    i18nc("@title:window", "Warning"),
+                                                    i18nc("@title: window change user", "Warning"),
                                                     i18nc("@info", "You will be logged out of your account, "
                                                           "click \"Continue\" to authenticate for another account"),
                                                     QMessageBox::Yes | QMessageBox::No);
 
-    (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-    (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+    (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button change user", "Continue"));
+    (warn->button(QMessageBox::No))->setText(i18nc("@action: button change user", "Cancel"));
 
     if (warn->exec() == QMessageBox::Yes)
     {
@@ -1301,17 +1341,21 @@ void GSWindow::slotUserChangeRequest()
         switch (d->service)
         {
             case GoogleService::GDrive:
+            {
                 d->talker->unlink();
                 while(d->talker->authenticated());
                 d->talker->doOAuth();
                 break;
+            }
 
             case GoogleService::GPhotoImport:
             case GoogleService::GPhotoExport:
+            {
                 d->gphotoTalker->unlink();
                 while(d->gphotoTalker->authenticated());
                 d->gphotoTalker->doOAuth();
                 break;
+            }
         }
     }
 
