@@ -46,21 +46,16 @@ class Q_DECL_HIDDEN ODWindow::Private
 {
 public:
 
-    explicit Private()
-    {
-        imagesCount = 0;
-        imagesTotal = 0;
-        widget      = nullptr;
-        albumDlg    = nullptr;
-        talker      = nullptr;
-    }
+    Private() = default;
 
-    unsigned int   imagesCount;
-    unsigned int   imagesTotal;
+public:
 
-    ODWidget*      widget;
-    ODNewAlbumDlg* albumDlg;
-    ODTalker*      talker;
+    unsigned int   imagesCount  = 0;
+    unsigned int   imagesTotal  = 0;
+
+    ODWidget*      widget       = nullptr;
+    ODNewAlbumDlg* albumDlg     = nullptr;
+    ODTalker*      talker       = nullptr;
 
     QString        currentAlbumName;
     QList<QUrl>    transferQueue;
@@ -77,10 +72,10 @@ ODWindow::ODWindow(DInfoInterface* const iface,
 
     setMainWidget(d->widget);
     setModal(false);
-    setWindowTitle(i18nc("@title:window", "Export to Onedrive"));
+    setWindowTitle(i18nc("@title:window", "Export to OneDrive"));
 
     startButton()->setText(i18nc("@action:button", "Start Upload"));
-    startButton()->setToolTip(i18nc("@info:tooltip, button", "Start upload to Onedrive"));
+    startButton()->setToolTip(i18nc("@info:tooltip, button", "Start upload to OneDrive"));
 
     d->widget->setMinimumSize(700, 500);
 
@@ -240,7 +235,7 @@ void ODWindow::slotStartTransfer()
 
     if (d->widget->imagesList()->imageUrls().isEmpty())
     {
-        QMessageBox::critical(this, i18nc("@title:window", "Error"),
+        QMessageBox::critical(this, i18nc("@title: window start transfer", "Error"),
                               i18nc("@info", "No image selected. Please select which images should be uploaded."));
         return;
     }
@@ -248,12 +243,12 @@ void ODWindow::slotStartTransfer()
     if (!(d->talker->authenticated()))
     {
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                         i18nc("@title:window", "Warning"),
+                         i18nc("@title: window start transfer", "Warning"),
                          i18nc("@info", "Authentication failed. Click \"Continue\" to authenticate."),
                          QMessageBox::Yes | QMessageBox::No);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-        (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button start transfer", "Continue"));
+        (warn->button(QMessageBox::No))->setText(i18nc("@action: button start transfer", "Cancel"));
 
         if (warn->exec() == QMessageBox::Yes)
         {
@@ -278,14 +273,14 @@ void ODWindow::slotStartTransfer()
     d->currentAlbumName = d->widget->getAlbumsCoB()->itemData(d->widget->getAlbumsCoB()->currentIndex()).toString();
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "StartTransfer:" << d->currentAlbumName
                                      << "INDEX: " << d->widget->getAlbumsCoB()->currentIndex();
-    d->imagesTotal = d->transferQueue.count();
-    d->imagesCount = 0;
+    d->imagesTotal      = d->transferQueue.count();
+    d->imagesCount      = 0;
 
     d->widget->progressBar()->setFormat(i18nc("@info: progress bar", "%v / %m"));
     d->widget->progressBar()->setMaximum(d->imagesTotal);
     d->widget->progressBar()->setValue(0);
     d->widget->progressBar()->show();
-    d->widget->progressBar()->progressScheduled(i18nc("@info", "Onedrive export"), true, true);
+    d->widget->progressBar()->progressScheduled(i18nc("@info", "OneDrive export"), true, true);
     d->widget->progressBar()->progressThumbnailChanged(
         QIcon::fromTheme(QLatin1String("dk-onedrive")).pixmap(22, 22));
 
@@ -396,12 +391,12 @@ void ODWindow::slotSignalLinkingSucceeded()
 
 void ODWindow::slotListAlbumsFailed(const QString& msg)
 {
-    QMessageBox::critical(this, QString(), i18nc("@info", "Onedrive call failed:\n%1", msg));
+    QMessageBox::critical(this, QString(), i18nc("@info", "OneDrive call failed:\n%1", msg));
 }
 
 void ODWindow::slotCreateFolderFailed(const QString& msg)
 {
-    QMessageBox::critical(this, QString(), i18nc("@info", "Onedrive call failed:\n%1", msg));
+    QMessageBox::critical(this, QString(), i18nc("@info", "OneDrive call failed:\n%1", msg));
 }
 
 void ODWindow::slotCreateFolderSucceeded()
