@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2006      by Colin Guthrie <kde at colin dot guthr dot ie>
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2008      by Andrea Diamantini <adjam7 at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2014 by Frederic Coiffier <frederic dot coiffier at free dot com>
  *
@@ -16,8 +16,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_PIWIGO_ITEM_H
-#define DIGIKAM_PIWIGO_ITEM_H
+#pragma once
 
 // Qt includes
 
@@ -30,11 +29,7 @@ class PiwigoAlbum
 {
 public:
 
-    explicit PiwigoAlbum()
-      : m_refNum      (-1),
-        m_parentRefNum(-1)
-    {
-    }
+    PiwigoAlbum() = default;
 
     bool operator<(const PiwigoAlbum& rhs) const
     {
@@ -48,12 +43,10 @@ public:
 
 public:
 
-    int     m_refNum;         ///< album reference number
-    int     m_parentRefNum;   ///< parent's album reference number
+    int     m_refNum        = -1;   ///< album reference number
+    int     m_parentRefNum  = -1;   ///< parent's album reference number
 
-    QString m_name;           ///< Album name
+    QString m_name;                 ///< Album name
 };
 
 } // namespace DigikamGenericPiwigoPlugin
-
-#endif // DIGIKAM_PIWIGO_ITEM_H
