@@ -46,27 +46,21 @@ class Q_DECL_HIDDEN TwWindow::Private
 {
 public:
 
-    explicit Private()
-      : imagesCount(0),
-        imagesTotal(0),
-        widget     (nullptr),
-        albumDlg   (nullptr),
-        talker     (nullptr)
-    {
-    }
+    Private() = default;
 
-    unsigned int   imagesCount;
-    unsigned int   imagesTotal;
+public:
 
-    TwWidget*      widget;
-    TwNewAlbumDlg* albumDlg;
-    TwTalker*      talker;
+    unsigned int   imagesCount          = 0;
+    unsigned int   imagesTotal          = 0;
+
+    TwWidget*      widget               = nullptr;
+    TwNewAlbumDlg* albumDlg             = nullptr;
+    TwTalker*      talker               = nullptr;
 
     QString        currentAlbumName;
     QList<QUrl>    transferQueue;
 };
 
-
 TwWindow::TwWindow(DInfoInterface* const iface,
                    QWidget* const /*parent*/)
     : WSToolDialog(nullptr, QLatin1String("Twitter Export Dialog")),
@@ -153,7 +147,7 @@ TwWindow::~TwWindow()
 void TwWindow::readSettings()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup grp        = config->group("Twitter Settings");
+    KConfigGroup grp        = config->group(QLatin1String("Twitter Settings"));
     d->currentAlbumName     = grp.readEntry("Current Album", QString());
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "readsettings:" << d->currentAlbumName;
 
@@ -175,7 +169,7 @@ void TwWindow::readSettings()
 void TwWindow::writeSettings()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup grp        = config->group("Twitter Settings");
+    KConfigGroup grp        = config->group(QLatin1String("Twitter Settings"));
 
     grp.writeEntry("Current Album", d->currentAlbumName);
     grp.writeEntry("Resize",        d->widget->getResizeCheckBox()->isChecked());
@@ -245,7 +239,7 @@ void TwWindow::slotStartTransfer()
 
     if (d->widget->imagesList()->imageUrls().isEmpty())
     {
-        QMessageBox::critical(this, i18nc("@title:window", "Error"),
+        QMessageBox::critical(this, i18nc("@title: window start transfer", "Error"),
                               i18n("No image selected. Please select which images should be uploaded."));
         return;
     }
@@ -253,12 +247,12 @@ void TwWindow::slotStartTransfer()
     if (!(d->talker->authenticated()))
     {
         QPointer<QMessageBox> warn = new QMessageBox(QMessageBox::Warning,
-                         i18nc("@title:window", "Warning"),
+                         i18nc("@title: window start transfer", "Warning"),
                          i18n("Authentication failed. Click \"Continue\" to authenticate."),
                          QMessageBox::Yes | QMessageBox::No);
 
-        (warn->button(QMessageBox::Yes))->setText(i18nc("@action:button", "Continue"));
-        (warn->button(QMessageBox::No))->setText(i18nc("@action:button", "Cancel"));
+        (warn->button(QMessageBox::Yes))->setText(i18nc("@action: button start transfer", "Continue"));
+        (warn->button(QMessageBox::No))->setText(i18nc("@action: button start transfer", "Cancel"));
 
         if (warn->exec() == QMessageBox::Yes)
         {
@@ -370,6 +364,7 @@ void TwWindow::slotNewAlbumRequest()
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "slotNewAlbumRequest:" << newAlbum.title;
         d->currentAlbumName = d->widget->getAlbumsCoB()->itemData(d->widget->getAlbumsCoB()->currentIndex()).toString();
         QString temp = d->currentAlbumName + newAlbum.title;
+        Q_UNUSED(temp);
 /*
         d->talker->createFolder(temp);
 */
@@ -461,3 +456,5 @@ void TwWindow::closeEvent(QCloseEvent* e)
 }
 
 } // namespace DigikamGenericTwitterPlugin
+
+#include "moc_twitterwindow.cpp"
