@@ -6,14 +6,13 @@
  * Date        : 2017-06-27
  * Description : a tool to export items to web services.
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_WS_ALBUMS_PAGE_H
-#define DIGIKAM_WS_ALBUMS_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -43,9 +42,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericUnifiedPlugin
-
-#endif // DIGIKAM_WS_ALBUMS_PAGE_H
