@@ -9,7 +9,7 @@
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
  * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -47,7 +47,7 @@ void CollectionScanner::setPerformFastScan(bool on)
 
 CollectionScannerHintContainer* CollectionScanner::createHintContainer()
 {
-    return new CollectionScannerHintContainerImplementation;
+    return (new CollectionScannerHintContainerImplementation);
 }
 
 void CollectionScanner::setHintContainer(CollectionScannerHintContainer* const container)
