@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
  * SPDX-FileCopyrightText: 2007-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -45,7 +45,7 @@ void CollectionScanner::completeScan()
 
         int count = 0;
 
-        Q_FOREACH (const CollectionLocation& location, allLocations)
+        for (const CollectionLocation& location : std::as_const(allLocations))
         {
             // cppcheck-suppress useStlAlgorithm
             count += countItemsInFolder(location.albumRootPath());
@@ -82,7 +82,7 @@ void CollectionScanner::completeScan()
         Q_EMIT startScanningAlbumRoots();
     }
 
-    Q_FOREACH (const CollectionLocation& location, allLocations)
+    for (const CollectionLocation& location : std::as_const(allLocations))
     {
         scanAlbumRoot(location);
     }
@@ -160,7 +160,7 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
 
         int count = 0;
 
-        Q_FOREACH (const QString& path, sortedPaths)
+        for (const QString& path : std::as_const(sortedPaths))
         {
             // cppcheck-suppress useStlAlgorithm
             count += countItemsInFolder(path);
@@ -169,7 +169,7 @@ void CollectionScanner::finishCompleteScan(const QStringList& albumPaths)
         Q_EMIT totalFilesToScan(count);
     }
 
-    Q_FOREACH (const QString& path, sortedPaths)
+    for (const QString& path : std::as_const(sortedPaths))
     {
         CollectionLocation location = CollectionManager::instance()->locationForPath(path);
         QString album               = CollectionManager::instance()->album(path);
@@ -214,7 +214,7 @@ void CollectionScanner::completeScanCleanupPart()
         CoreDbAccess access;
         QList<qlonglong> trashedItems = access.db()->getImageIds(DatabaseItem::Status::Trashed);
 
-        Q_FOREACH (const qlonglong& item, trashedItems)
+        for (const qlonglong& item : std::as_const(trashedItems))
         {
             access.db()->setItemStatus(item, DatabaseItem::Status::Obsolete);
         }
@@ -523,7 +523,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<CollectionLocation>& loca
 {
     QList<int> locationIdsToScan;
 
-    Q_FOREACH (const CollectionLocation& location, locations)
+    for (const CollectionLocation& location : std::as_const(locations))
     {
         locationIdsToScan << location.id();
     }
@@ -539,27 +539,11 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
     }
 
     QList<AlbumShortInfo> albumList = CoreDbAccess().db()->getAlbumShortInfos();
-    QList<int> toBeDeleted;
-    int counter = 0;
-
-    if (d->wantSignals && d->needTotalFiles)
-    {
-        Q_EMIT totalFilesToScan(albumList.count());
-    }
-
     QList<AlbumShortInfo>::const_iterator it3;
+    QList<int> toBeDeleted;
 
     for (it3 = albumList.constBegin() ; it3 != albumList.constEnd() ; ++it3)
     {
-        ++counter;
-
-        if (d->wantSignals && counter && (counter % 10 == 0))
-        {
-            Q_EMIT scannedFiles(counter);
-
-            counter = 0;
-        }
-
         if (!locationIdsToScan.contains((*it3).albumRootId) || toBeDeleted.contains((*it3).id))
         {
             continue;
@@ -713,9 +697,9 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
         Q_EMIT startScanningAlbum(location.albumRootPath(), album);
     }
 
-    int albumID                          = checkAlbum(location, album);
-    QDateTime albumDateTime              = asDateTimeUTC(QFileInfo(dir.path()).lastModified());
-    QDateTime albumModified              = CoreDbAccess().db()->getAlbumModificationDate(albumID);
+    int albumID             = checkAlbum(location, album);
+    QDateTime albumDateTime = asDateTimeUTC(QFileInfo(dir.path()).lastModified());
+    QDateTime albumModified = CoreDbAccess().db()->getAlbumModificationDate(albumID);
 
     if (checkDate && s_modificationDateEquals(albumDateTime, albumModified))
     {
@@ -734,6 +718,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     const QList<ItemScanInfo>& scanInfos = CoreDbAccess().db()->getItemScanInfos(albumID);
     MetaEngineSettingsContainer settings = MetaEngineSettings::instance()->settings();
     QHash<QString, int> fileNameIndexHash;
+    QHash<QString, QFileInfo> nameInfos;
     QSet<qlonglong> itemIdSet;
 
     // create a QHash filename -> index in list
@@ -749,13 +734,18 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
                                                   QDir::NoDotAndDotDot,
                                                   QDir::Name | QDir::DirsLast);
 
+    for (const QFileInfo& info : std::as_const(list))
+    {
+        nameInfos.insert(info.fileName(), info);
+    }
+
     int counter          = 0;
     bool updateAlbumDate = false;
     QDate albumDateOld   = albumDateTime.date();
     QDate albumDateNew   = albumDateTime.date();
     const QString xmpExt(QLatin1String(".xmp"));
 
-    Q_FOREACH (const QFileInfo& info, list)
+    for (const QFileInfo& info : std::as_const(list))
     {
         if (!d->checkObserver())
         {
@@ -804,15 +794,10 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
                         sidecarName = info.completeBaseName() + xmpExt;
                     }
 
-                    for (int i = 0 ; i < list.size() ; ++i)
+                    if (nameInfos.contains(sidecarName))
                     {
-                        if (list.at(i).fileName() == sidecarName)
-                        {
-                            sinfo      = &list.at(i);
-                            hasSidecar = true;
-
-                            break;
-                        }
+                        sinfo      = &nameInfos[sidecarName];
+                        hasSidecar = true;
                     }
                 }
 
@@ -833,7 +818,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
                 if (imageId > 0)
                 {
                     ItemInfo itemInfo(imageId);
-                    QDate itemDate    = itemInfo.dateTime().date();
+                    QDate itemDate = itemInfo.dateTime().date();
 
                     if (itemDate.isValid())
                     {
@@ -1266,7 +1251,7 @@ void CollectionScanner::finishHistoryScanning()
 
 void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
 {
-    Q_FOREACH (const qlonglong& id, ids)
+    for (const qlonglong& id : std::as_const(ids))
     {
         if (!d->checkObserver())
         {
@@ -1280,7 +1265,7 @@ void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
             QList<qlonglong> needTaggingIds;
             ItemScanner::resolveImageHistory(id, &needTaggingIds);
 
-            Q_FOREACH (const qlonglong& needTag, needTaggingIds)
+            for (const qlonglong& needTag : std::as_const(needTaggingIds))
             {
                 d->needTaggingHistorySet << needTag;
             }
@@ -1294,7 +1279,7 @@ void CollectionScanner::historyScanningStage2(const QList<qlonglong>& ids)
 
 void CollectionScanner::historyScanningStage3(const QList<qlonglong>& ids)
 {
-    Q_FOREACH (const qlonglong& id, ids)
+    for (const qlonglong& id : std::as_const(ids))
     {
         if (!d->checkObserver())
         {
