@@ -100,6 +100,7 @@ Qt::SortOrder ItemSortSettings::defaultSortOrderForCategorizationMode(Categoriza
     {
         case OneCategory:
         case NoCategories:
+        case CategoryByDay:
         case CategoryByAlbum:
         case CategoryByMonth:
         case CategoryByFormat:
@@ -198,17 +199,6 @@ int ItemSortSettings::compareCategories(const ItemInfo& left, const ItemInfo& ri
                                   categorizationCaseSensitivity, strTypeNatural);
         }
 
-        case CategoryByMonth:
-        {
-            int leftMonth  = left.dateTime().date().year()  * 100 +
-                             left.dateTime().date().month();
-            int rightMonth = right.dateTime().date().year() * 100 +
-                             right.dateTime().date().month();
-
-            return compareByOrder(leftMonth, rightMonth,
-                                  currentCategorizationSortOrder);
-        }
-
         case CategoryByFaces:
         {
             if (leftFace.isNull() && rightFace.isNull())
@@ -237,11 +227,11 @@ int ItemSortSettings::compareCategories(const ItemInfo& left, const ItemInfo& ri
             {
                 if (currentCategorizationSortOrder == Qt::AscendingOrder)
                 {
-                    return isLeftUnknown ? 1 : -1;
+                    return (isLeftUnknown ? 1 : -1);
                 }
                 else
                 {
-                    return isLeftUnknown ? -1 : 1;
+                    return (isLeftUnknown ? -1 : 1);
                 }
             }
 
@@ -282,9 +272,43 @@ int ItemSortSettings::compareCategories(const ItemInfo& left, const ItemInfo& ri
 
             // Compare alphabetically based on the face name
 
-            return naturalCompare(leftValue, rightValue,
+            return naturalCompare(
+                                  leftValue,
+                                  rightValue,
                                   currentCategorizationSortOrder,
-                                  categorizationCaseSensitivity, strTypeNatural);
+                                  categorizationCaseSensitivity,
+                                  strTypeNatural
+                                 );
+        }
+
+        case CategoryByMonth:
+        {
+            int leftMonth  = left.dateTime().date().year()  * 100 +
+                             left.dateTime().date().month();
+            int rightMonth = right.dateTime().date().year() * 100 +
+                             right.dateTime().date().month();
+
+            return compareByOrder(
+                                  leftMonth,
+                                  rightMonth,
+                                  currentCategorizationSortOrder
+                                 );
+        }
+
+        case CategoryByDay:
+        {
+            int leftDay  = (left.dateTime().date().year()   * 100 +
+                            left.dateTime().date().month()) * 100 +
+                            left.dateTime().date().day();
+            int rightDay = (right.dateTime().date().year()   * 100 +
+                            right.dateTime().date().month()) * 100 +
+                            right.dateTime().date().day();
+
+            return compareByOrder(
+                                  leftDay,
+                                  rightDay,
+                                  currentCategorizationSortOrder
+                                 );
         }
 
         default:
@@ -366,14 +390,23 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
     {
         case SortByFileName:
         {
-            return naturalCompare(left.name(), right.name(),
-                                  currentSortOrder, sortCaseSensitivity, strTypeNatural);
+            return naturalCompare(left.name(),
+                                  right.name(),
+                                  currentSortOrder,
+                                  sortCaseSensitivity,
+                                  strTypeNatural
+                                 );
         }
 
         case SortByFilePath:
         {
-            return naturalCompare(left.filePath(), right.filePath(),
-                                  currentSortOrder, sortCaseSensitivity, strTypeNatural);
+            return naturalCompare(
+                                  left.filePath(),
+                                  right.filePath(),
+                                  currentSortOrder,
+                                  sortCaseSensitivity,
+                                  strTypeNatural
+                                 );
         }
 
         case SortByFileSize:
@@ -453,8 +486,13 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
                 return compareByOrder(left.dateTime(), right.dateTime(), currentSortOrder);
             }
 
-            return naturalCompare(left.name(), right.name(),
-                                  currentSortOrder, sortCaseSensitivity, strTypeNatural);
+            return naturalCompare(
+                                  left.name(),
+                                  right.name(),
+                                  currentSortOrder,
+                                  sortCaseSensitivity,
+                                  strTypeNatural
+                                 );
         }
 
         default:
@@ -492,48 +530,131 @@ bool ItemSortSettings::lessThan(const QVariant& left, const QVariant& right) con
 #endif
 
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::Int:
+
+#else
+
         case QVariant::Int:
+
+#endif
+
         {
             return compareByOrder(left.toInt(), right.toInt(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::UInt:
+
+#else
+
         case QVariant::UInt:
+
+#endif
+
         {
             return compareByOrder(left.toUInt(), right.toUInt(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::LongLong:
+
+#else
+
         case QVariant::LongLong:
+
+#endif
+
         {
             return compareByOrder(left.toLongLong(), right.toLongLong(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::ULongLong:
+
+#else
+
         case QVariant::ULongLong:
+
+#endif
+
         {
             return compareByOrder(left.toULongLong(), right.toULongLong(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::Double:
+
+#else
+
         case QVariant::Double:
+
+#endif
+
         {
             return compareByOrder(left.toDouble(), right.toDouble(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::QDate:
+
+#else
+
         case QVariant::Date:
+
+#endif
+
         {
             return compareByOrder(left.toDate(), right.toDate(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::QDateTime:
+
+#else
+
         case QVariant::DateTime:
+
+#endif
+
         {
             return compareByOrder(left.toDateTime(), right.toDateTime(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::QTime:
+
+#else
+
         case QVariant::Time:
+
+#endif
+
         {
             return compareByOrder(left.toTime(), right.toTime(), currentSortOrder);
         }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        case QMetaType::QRect:
+        case QMetaType::QRectF:
+
+#else
+
         case QVariant::Rect:
         case QVariant::RectF:
+
+#endif
+
         {
             QRectF rectLeft  = left.toRectF();
             QRectF rectRight = right.toRectF();
@@ -567,8 +688,13 @@ bool ItemSortSettings::lessThan(const QVariant& left, const QVariant& right) con
 
         default:
         {
-            return naturalCompare(left.toString(), right.toString(),
-                                  currentSortOrder, sortCaseSensitivity, strTypeNatural);
+            return naturalCompare(
+                                  left.toString(),
+                                  right.toString(),
+                                  currentSortOrder,
+                                  sortCaseSensitivity,
+                                  strTypeNatural
+                                 );
         }
     }
 }
@@ -671,6 +797,7 @@ DatabaseFields::Set ItemSortSettings::watchFlags() const
         }
 
         case CategoryByMonth:
+        case CategoryByDay:
         {
             set |= DatabaseFields::CreationDate;
             break;
