@@ -6,7 +6,7 @@
  * Date        : 2017-05-06
  * Description : interface to database information for shared tools.
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  * SPDX-FileCopyrightText: 2017      by Mario Frank <mario dot frank at uni minus potsdam dot de>
  *
@@ -53,6 +53,7 @@
 #include "fileactionmngr.h"
 #include "tagsactionmngr.h"
 #include "setup.h"
+#include "applicationsettings.h"
 
 #ifdef HAVE_GEOLOCATION
 #   include "itemgps.h"
@@ -67,15 +68,15 @@ public:
 
     Private() = default;
 
-    AlbumManager*                      albumManager     = AlbumManager::instance();
-    AlbumSelectTabs*                   albumsChooser    = nullptr;
-    AlbumSelectWidget*                 albumSelector    = nullptr;
+    AlbumManager*        albumManager     = AlbumManager::instance();
+    AlbumSelectTabs*     albumsChooser    = nullptr;
+    AlbumSelectWidget*   albumSelector    = nullptr;
 
-    QList<QUrl>                        itemUrls;
+    QList<QUrl>          itemUrls;
 
-    ApplicationSettings::OperationType operationType    = ApplicationSettings::Unspecified;
-    bool                               withGroupedIsSet = false;
-    bool                               withGrouped      = false;
+    OperationType        operationType    = UnspecifiedOps;
+    bool                 withGroupedIsSet = false;
+    bool                 withGrouped      = false;
 
 public:
 
@@ -173,9 +174,10 @@ public:
             QList<int> list;
             list << reader.valueToIntList();
 
-            Q_FOREACH (int imageId, list)
+            for (int imageId : std::as_const(list))
             {
                 ItemInfo imageInfo(imageId);
+
                 if (imageInfo.isVisible())
                 {
                     // if the image is visible, i.e. existent and not deleted,
@@ -215,7 +217,7 @@ public:
             {
                 // if there were no error, fetch and process the results.
 
-                Q_FOREACH (const ItemListerRecord &record, receiver.records)
+                for (const ItemListerRecord& record : std::as_const(receiver.records))
                 {
                     ItemInfo imageInfo(record);
                     QUrl imageUrl = imageInfo.fileUrl();
@@ -243,7 +245,7 @@ public:
 
         if (!(withGroupedIsSet && withGrouped))
         {
-            Q_FOREACH (const QUrl& url, urlList)
+            for (const QUrl& url : std::as_const(urlList))
             {
                 ItemInfo info = ItemInfo::fromUrl(url);
 
@@ -260,7 +262,9 @@ public:
                         }
                     }
 
-                    Q_FOREACH (const ItemInfo& i, info.groupedImages())
+                    const auto imgs = info.groupedImages();
+
+                    for (const ItemInfo& i : imgs)
                     {
                         lst.removeOne(i.fileUrl());
                     }
@@ -286,7 +290,7 @@ public:
 };
 
 DBInfoIface::DBInfoIface(QObject* const parent, const QList<QUrl>& lst,
-                         const ApplicationSettings::OperationType type)
+                         const OperationType type)
     : DInfoInterface(parent),
       d             (new Private)
 {
@@ -517,7 +521,7 @@ DBInfoIface::DInfoMap DBInfoIface::itemInfo(const QUrl& url) const
     }
     else
     {
-        qCDebug(DIGIKAM_GENERAL_LOG) << "Database Info is NULL for" << url;
+        qCDebug(DIGIKAM_GENERAL_LOG) << "Database Info is null for" << url;
     }
 
     return map;
@@ -674,7 +678,7 @@ QList<QUrl> DBInfoIface::albumsItems(const DAlbumIDs& lst) const
 {
     QList<QUrl> imageList;
 
-    Q_FOREACH (int gid, lst)
+    for (int gid : std::as_const(lst))
     {
         imageList << albumItems(gid);
     }
@@ -705,7 +709,7 @@ DBInfoIface::DAlbumIDs DBInfoIface::albumChooserItems() const
     AlbumList lst = d->albumsChooser->selectedAlbums();
     DAlbumIDs ids;
 
-    Q_FOREACH (Album* const a, lst)
+    for (Album* const a : std::as_const(lst))
     {
         if (a)
         {
@@ -761,9 +765,15 @@ QUrl DBInfoIface::defaultUploadUrl() const
         place = QUrl::fromLocalFile(pics.first());
     }
 
-    Album* const album = AlbumManager::instance()->currentAlbums().first();
+    QList<Album*> albumList = AlbumManager::instance()->currentAlbums();
+    Album* album            = nullptr;
 
-    if (album->type() == Album::PHYSICAL)
+    if (!albumList.isEmpty())
+    {
+        album = albumList.first();
+    }
+
+    if (album && (album->type() == Album::PHYSICAL))
     {
         PAlbum* const p = dynamic_cast<PAlbum*>(album);
 
@@ -800,8 +810,9 @@ QAbstractItemModel* DBInfoIface::tagFilterModel()
 QList<GPSItemContainer*> DBInfoIface::currentGPSItems() const
 {
     QList<GPSItemContainer*> items;
+    const auto urls = currentSelectedItems();
 
-    Q_FOREACH (const QUrl& url, currentSelectedItems())
+    for (const QUrl& url : urls)
     {
         ItemInfo info = ItemInfo::fromUrl(url);
         items << new ItemGPS(info);
@@ -846,18 +857,9 @@ void DBInfoIface::openSetupPage(SetupPage page)
             break;
         }
 
-        case ImageQualityPage:
-        {
-            if (Setup::execImageQualitySorter(nullptr))
-            {
-                Q_EMIT signalSetupChanged();
-            }
-
-            break;
-        }
-
         default:
         {
+            break;
         }
     }
 }
