@@ -69,22 +69,17 @@ Q_GLOBAL_STATIC(DIOCreator, creator)
 
 // ------------------------------------------------------------------------------------------------
 
+DIO::DIO()
+    : QObject()
+{
+    qRegisterMetaType<QMap<QString,int> >("QMap<QString,int>");
+}
+
 DIO* DIO::instance()
 {
     return &creator->object;
 }
 
-DIO::DIO()
-{
-    qRegisterMetaType<QMap<QString,int>>("QMap<QString,int>");
-
-    m_processingCount = 0;
-}
-
-DIO::~DIO()
-{
-}
-
 void DIO::cleanUp()
 {
 }
@@ -234,7 +229,7 @@ int DIO::getTrashCounter(const QString& albumRootPath)
     QUrl url = QUrl::fromLocalFile(albumRootPath);
     url      = url.adjusted(QUrl::StripTrailingSlash);
 
-    QMutexLocker locker(&instance()->m_trashCounterMutex);
+    QMutexLocker locker(&instance()->m_dioMutex);
 
     return instance()->m_trashCounterMap.value(url.toLocalFile(), 0);
 }
@@ -269,16 +264,20 @@ void DIO::processJob(IOJobData* const data)
 {
     const int operation = data->operation();
 
-    if      ((operation == IOJobData::CopyImage) ||
-             (operation == IOJobData::MoveImage))
+    if      (
+             (operation == IOJobData::CopyImage) ||
+             (operation == IOJobData::MoveImage)
+            )
     {
         // this is a fast db operation, do here
 
         GroupedImagesFinder finder(data->itemInfos());
         data->setItemInfos(finder.infos);
     }
-    else if ((operation == IOJobData::Trash) ||
-             (operation == IOJobData::Delete))
+    else if (
+             (operation == IOJobData::Trash) ||
+             (operation == IOJobData::Delete)
+            )
     {
         SidecarFinder finder(data->sourceUrls());
         data->setSourceUrls(finder.localFiles);
@@ -325,20 +324,56 @@ void DIO::createJob(IOJobData* const data)
 
     const int operation = data->operation();
 
-    if ((operation == IOJobData::CopyImage) || (operation == IOJobData::CopyAlbum) ||
+    if (
+        (operation == IOJobData::CopyImage) || (operation == IOJobData::CopyAlbum) ||
         (operation == IOJobData::CopyFiles) || (operation == IOJobData::CopyToExt) ||
         (operation == IOJobData::MoveImage) || (operation == IOJobData::MoveAlbum) ||
-        (operation == IOJobData::MoveFiles))
+        (operation == IOJobData::MoveFiles)
+       )
     {
         CollectionLocation location         = CollectionManager::instance()->locationForUrl(data->destUrl());
         Qt::CaseSensitivity caseSensitivity = location.asQtCaseSensitivity();
+        QList<QString> currentPathList;
+
+        {
+            QMutexLocker locker(&m_dioMutex);
+
+            currentPathList = m_currentPathHash.values();
+        }
+
+        for (const QString& cpath : std::as_const(currentPathList))
+        {
+            const auto src = data->sourceUrls();
+
+            for (const QUrl& url : src)
+            {
+                QFileInfo srcInfo(url.toLocalFile());
+
+                if (
+                    cpath.contains(data->destUrl().toLocalFile(), caseSensitivity)  ||
+                    cpath.contains(srcInfo.path() + QLatin1Char('/'), caseSensitivity)
+                   )
+                {
+                    QMessageBox::warning(qApp->activeWindow(),
+                                         i18nc("@title:window", "File Conflict"),
+                                         i18n("A file operation using the same path is currently in progress. "
+                                              "Please wait for the operation to complete and try again."));
+
+                    delete data;
+
+                    return;
+                }
+            }
+        }
+
         QDir dir(data->destUrl().toLocalFile());
+        const QStringList& dirList = dir.entryList(QDir::Dirs    |
+                                                   QDir::Files   |
+                                                   QDir::NoDotAndDotDot);
 
-        const QStringList& dirList          = dir.entryList(QDir::Dirs    |
-                                                            QDir::Files   |
-                                                            QDir::NoDotAndDotDot);
+        const auto src = data->sourceUrls();
 
-        Q_FOREACH (const QUrl& url, data->sourceUrls())
+        for (const QUrl& url : src)
         {
             if (dirList.contains(url.adjusted(QUrl::StripTrailingSlash).fileName(), caseSensitivity))
             {
@@ -386,6 +421,19 @@ void DIO::createJob(IOJobData* const data)
                 break;
             }
         }
+
+        {
+            QMutexLocker locker(&m_dioMutex);
+
+            m_currentPathHash.insert(data, data->destUrl().toLocalFile());
+            const auto urls = data->sourceUrls();
+
+            for (const QUrl& url : urls)
+            {
+                QFileInfo srcInfo(url.toLocalFile());
+                m_currentPathHash.insert(data, srcInfo.path() + QLatin1Char('/'));
+            }
+        }
     }
 
     ProgressItem* item = nullptr;
@@ -416,8 +464,10 @@ void DIO::createJob(IOJobData* const data)
                 this, SIGNAL(signalRenameFinished()));
     }
 
-    if ((operation == IOJobData::Empty) ||
-        (operation == IOJobData::Restore))
+    if (
+        (operation == IOJobData::Empty) ||
+        (operation == IOJobData::Restore)
+       )
     {
         connect(jobThread, SIGNAL(signalFinished()),
                 this, SIGNAL(signalTrashFinished()));
@@ -457,8 +507,10 @@ void DIO::slotResult()
     }
     else
     {
-        if ((operation == IOJobData::CopyImage) ||
-            (operation == IOJobData::MoveImage))
+        if (
+            (operation == IOJobData::CopyImage) ||
+            (operation == IOJobData::MoveImage)
+           )
         {
             if (data->destAlbum())
             {
@@ -466,11 +518,15 @@ void DIO::slotResult()
             }
         }
 
-        if ((operation == IOJobData::Trash)  ||
+        if (
+            (operation == IOJobData::Trash)  ||
             (operation == IOJobData::Delete) ||
-            (operation == IOJobData::MoveImage))
+            (operation == IOJobData::MoveImage)
+           )
         {
-            Q_FOREACH (int albumID, data->srcAlbumIds())
+            const auto ids = data->srcAlbumIds();
+
+            for (int albumID : ids)
             {
                 updateAlbumDate(albumID);
             }
@@ -478,22 +534,32 @@ void DIO::slotResult()
 
         if (data->errorOrCancel())
         {
-            if ((operation == IOJobData::CopyAlbum) ||
-                (operation == IOJobData::MoveAlbum))
+            if (
+                (operation == IOJobData::CopyAlbum) ||
+                (operation == IOJobData::MoveAlbum)
+               )
             {
                 QString scanPath = data->destUrl().adjusted(QUrl::StripTrailingSlash).toLocalFile();
                 ScanController::instance()->scheduleCollectionScanRelaxed(scanPath);
             }
         }
 
-        if ((operation == IOJobData::Trash) ||
+        if (
+            (operation == IOJobData::Trash) ||
             (operation == IOJobData::Empty) ||
-            (operation == IOJobData::Restore))
+            (operation == IOJobData::Restore)
+           )
         {
             buildCollectionTrashCounters();
         }
     }
 
+    {
+        QMutexLocker locker(&m_dioMutex);
+
+        m_currentPathHash.remove(data);
+    }
+
     if (m_processingCount)
     {
         --m_processingCount;
@@ -604,18 +670,18 @@ void DIO::slotOneProccessed(const QUrl& url)
 
                 addAlbumChildrenToList(albumsToCopy, data->srcAlbum());
 
-                Q_FOREACH (int albumId, albumsToCopy)
+                for (int albumId : std::as_const(albumsToCopy))
                 {
                     QString relativePath = access.db()->getAlbumRelativePath(albumId);
                     relativePath         = relativePath.section(basePath, 1, -1);
                     relativePath         = destPath + newName + relativePath;
+                    int copyId           = access.db()->addAlbum(data->srcAlbum()->albumRootId(),
+                                                                 relativePath, QString(), QDate(), QString());
 
-                    int copyId = access.db()->addAlbum(data->srcAlbum()->albumRootId(),
-                                                       relativePath, QString(), QDate(), QString());
                     access.db()->copyAlbumProperties(albumId, copyId);
                     const QList<qlonglong>& imageIds = access.db()->getItemIDsInAlbum(albumId);
 
-                    Q_FOREACH (const qlonglong& id, imageIds)
+                    for (const qlonglong& id : std::as_const(imageIds))
                     {
                         QString name     = access.db()->getItemName(id);
                         qlonglong itemId = access.db()->copyItem(albumId, name, copyId, name);
@@ -648,7 +714,7 @@ void DIO::slotOneProccessed(const QUrl& url)
 
                 addAlbumChildrenToList(albumsToMove, data->srcAlbum());
 
-                Q_FOREACH (int albumId, albumsToMove)
+                for (int albumId : std::as_const(albumsToMove))
                 {
                     QString relativePath = access.db()->getAlbumRelativePath(albumId);
                     relativePath         = relativePath.section(basePath, 1, -1);
@@ -680,12 +746,12 @@ void DIO::slotOneProccessed(const QUrl& url)
 
                 addAlbumChildrenToList(albumsToDelete, album);
 
-                Q_FOREACH (int albumId, albumsToDelete)
+                for (int albumId : std::as_const(albumsToDelete))
                 {
                     imagesToRemove << access.db()->getItemIDsInAlbum(albumId);
                 }
 
-                Q_FOREACH (const qlonglong& removeId, imagesToRemove)
+                for (const qlonglong& removeId : std::as_const(imagesToRemove))
                 {
                     ItemInfo info(removeId);
 
@@ -711,14 +777,14 @@ void DIO::slotOneProccessed(const QUrl& url)
                                                             QList<int>() << info.albumId());
                     }
 
-                    Q_FOREACH (const qlonglong& id, imageIdsFrom)
+                    for (const qlonglong& id : std::as_const(imageIdsFrom))
                     {
                         ItemScanner::resolveImageHistory(id);
                         ItemScanner::tagItemHistoryGraph(id);
                     }
                 }
 
-                Q_FOREACH (int albumId, albumsToDelete)
+                for (int albumId : std::as_const(albumsToDelete))
                 {
                     if (operation == IOJobData::Trash)
                     {
@@ -755,7 +821,7 @@ void DIO::slotOneProccessed(const QUrl& url)
                                                             QList<int>() << info.albumId());
                     }
 
-                    Q_FOREACH (const qlonglong& id, imageIdsFrom)
+                    for (const qlonglong& id : std::as_const(imageIdsFrom))
                     {
                         ItemScanner::resolveImageHistory(id);
                         ItemScanner::tagItemHistoryGraph(id);
@@ -935,7 +1001,7 @@ void DIO::slotCancel(ProgressItem* item)
 void DIO::slotTrashCounterMap(const QMap<QString, int>& counterMap)
 {
     {
-        QMutexLocker locker(&m_trashCounterMutex);
+        QMutexLocker locker(&m_dioMutex);
 
         m_trashCounterMap = counterMap;
     }
