@@ -5,28 +5,19 @@
  *
  * Date        : 2005-06-14
  * Description : digiKam 8/16 bits image management API.
- * Description : Smoothscale method based on Imlib2's implementations.
+ *               Smoothscale method based on Imlib2's implementations.
  *               https://git.enlightenment.org/legacy/imlib2.git/tree/src/lib/scale.c
  *               Ported to C++ and QImage
  *               Add smoothScaleSection to scale only an image section.
  *               Add 16 bits color depth image support.
  *
- * Copyright (C) 1999-2004 by Carsten Haitzler <raster at rasterman dot com>
- * Copyright (C) 2004      by Willem Monsuwe <willem at stack dot nl>
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005      by Daniel M. Duley <mosfet at interaccess dot com>
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 1999-2004 by Carsten Haitzler <raster at rasterman dot com>
+ * SPDX-FileCopyrightText: 2004      by Willem Monsuwe <willem at stack dot nl>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2005      by Daniel M. Duley <mosfet at interaccess dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -62,15 +53,7 @@ class Q_DECL_HIDDEN DImgScaleInfo
 {
 public:
 
-    DImgScaleInfo()
-      : xpoints  (nullptr),
-        ypoints  (nullptr),
-        ypoints16(nullptr),
-        xapoints (nullptr),
-        yapoints (nullptr),
-        xup_yup  (0)
-    {
-    }
+    DImgScaleInfo() = default;
 
     ~DImgScaleInfo()
     {
@@ -81,12 +64,22 @@ public:
         delete [] yapoints;
     }
 
-    int*     xpoints;
-    uint**   ypoints;
-    ullong** ypoints16;
-    int*     xapoints;
-    int*     yapoints;
-    int      xup_yup;
+public:
+
+    int*     xpoints     = nullptr;
+    uint**   ypoints     = nullptr;
+    ullong** ypoints16   = nullptr;
+    int*     xapoints    = nullptr;
+    int*     yapoints    = nullptr;
+    int      xup_yup     = 0;
+
+    bool     scaleSmooth = true;
+
+private:
+
+    // Disable
+    DImgScaleInfo(const DImgScaleInfo&)            = delete;
+    DImgScaleInfo& operator=(const DImgScaleInfo&) = delete;
 };
 
 uint**   dimgCalcYPoints(uint* const src, int sw, int sh, int dh);
@@ -97,175 +90,174 @@ int*     dimgCalcApoints(int s, int d, int up);
 DImgScaleInfo* dimgCalcScaleInfo(const DImg& img,
                                  int sw, int sh,
                                  int dw, int dh,
-                                 bool aa);
+                                 bool aa, bool smooth);
 /**
- * For internal scale by pixel sampling only not smoothed in 8 bits RGBA.
- * Arguments:
- *    isi:  scale info
- *    dest: destination image data
- *    dxx:  destination x location corresponding to start x of source section
- *    dyy:  destination y location corresponding to start y of source section
- *    dw:   destination width
- *    dh:   destination height
- *    dow:  destination scanline width
+ * @brief For internal scale by pixel sampling only not smoothed in 8 bits RGBA.
+ *
+ * @param isi  scale info
+ * @param dest destination image data
+ * @param dxx  destination x location corresponding to start x of source section
+ * @param dyy  destination y location corresponding to start y of source section
+ * @param dw   destination width
+ * @param dh   destination height
+ * @param dow  destination scanline width
  */
 void dimgSampleRGBA(DImgScaleInfo* const isi, uint* const dest,
                     int dxx, int dyy, int dw, int dh, int dow);
 
 /**
- * For internal scale by pixel sampling only not smoothed by area sampling in 8 bits RGBA.
- * Arguments:
- *    isi:     scale info
- *    dest:    destination image data
- *    dxx:     destination x location corresponding to start x of source section
- *    dyy:     destination y location corresponding to start y of source section
- *    dw:      destination width
- *    dh:      destination height
- *    dow:     destination scanline width
- *    clip_dx: clipped destination x location corresponding to start x
- *    clip_dy: clipped destination y location corresponding to start y
- *    clip_dw: clipped destination width
- *    clip_dh: clipped destination height
+ * @brief For internal scale by pixel sampling only not smoothed by area sampling in 8 bits RGBA.
+ *
+ * @param isi     scale info
+ * @param dest    destination image data
+ * @param dxx     destination x location corresponding to start x of source section
+ * @param dyy     destination y location corresponding to start y of source section
+ * @param dw      destination width
+ * @param dh      destination height
+ * @param dow     destination scanline width
+ * @param clip_dx clipped destination x location corresponding to start x
+ * @param clip_dy clipped destination y location corresponding to start y
+ * @param clip_dw clipped destination width
+ * @param clip_dh clipped destination height
  */
 void dimgSampleRGBA(DImgScaleInfo* const isi, uint* const dest,
                     int dxx, int dyy, int dw, int dh, int dow,
                     int clip_dx, int clip_dy, int clip_dw, int clip_dh);
 
 /**
- * For internal scale by pixel sampling only not smoothed in 16 bits RGBA.
- * Arguments:
- *    isi:  scale info
- *    dest: destination image data
- *    dxx:  destination x location corresponding to start x of source section
- *    dyy:  destination y location corresponding to start y of source section
- *    dw:   destination width
- *    dh:   destination height
- *    dow:  destination scanline width
+ * @brief For internal scale by pixel sampling only not smoothed in 16 bits RGBA.
+ *
+ * @param isi  scale info
+ * @param dest destination image data
+ * @param dxx  destination x location corresponding to start x of source section
+ * @param dyy  destination y location corresponding to start y of source section
+ * @param dw   destination width
+ * @param dh   destination height
+ * @param dow  destination scanline width
  */
 void dimgSampleRGBA16(DImgScaleInfo* const isi, ullong* const dest,
                       int dxx, int dyy, int dw, int dh, int dow);
 
 /**
- * For internal scale by pixel sampling only not smoothed by area sampling in 16 bits RGBA
- * Arguments:
- *    isi:     scale info
- *    dest:    destination image data
- *    dxx:     destination x location corresponding to start x of source section
- *    dyy:     destination y location corresponding to start y of source section
- *    dw:      destination width
- *    dh:      destination height
- *    dow:     destination scanline width
- *    clip_dx: clipped destination x location corresponding to start x
- *    clip_dy: clipped destination y location corresponding to start y
- *    clip_dw: clipped destination width
- *    clip_dh: clipped destination height
+ * @brief For internal scale by pixel sampling only not smoothed by area sampling in 16 bits RGBA
+ *
+ * @param isi     scale info
+ * @param dest    destination image data
+ * @param dxx     destination x location corresponding to start x of source section
+ * @param dyy     destination y location corresponding to start y of source section
+ * @param dw      destination width
+ * @param dh      destination height
+ * @param dow     destination scanline width
+ * @param clip_dx clipped destination x location corresponding to start x
+ * @param clip_dy clipped destination y location corresponding to start y
+ * @param clip_dw clipped destination width
+ * @param clip_dh clipped destination height
  */
 void dimgSampleRGBA16(DImgScaleInfo* const isi, ullong* const dest,
                       int dxx, int dyy, int dw, int dh, int dow,
                       int clip_dx, int clip_dy, int clip_dw, int clip_dh);
 
 /**
- * For internal scale in 8 bits RGBA
- * Arguments:
- *    isi:  scale info
- *    dest: destination image data
- *    dxx:  destination x location corresponding to start x of source section
- *    dyy:  destination y location corresponding to start y of source section
- *    dw:   destination width
- *    dh:   destination height
- *    dow:  destination scanline width
- *    sow:  source scanline width
+ * @brief For internal scale in 8 bits RGBA
+ *
+ * @param isi  scale info
+ * @param dest destination image data
+ * @param dxx  destination x location corresponding to start x of source section
+ * @param dyy  destination y location corresponding to start y of source section
+ * @param dw   destination width
+ * @param dh   destination height
+ * @param dow  destination scanline width
+ * @param sow  source scanline width
  */
 void dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
                      int dxx, int dyy, int dw, int dh, int dow, int sow);
 
 /**
- * For internal scale by area sampling in 8 bits RGBA
- * Arguments:
- *    isi:     scale info
- *    dest:    destination image data
- *    dxx:     destination x location corresponding to start x of source section
- *    dyy:     destination y location corresponding to start y of source section
- *    dw:      destination width
- *    dh:      destination height
- *    dow:     destination scanline width
- *    sow:     source scanline width
- *    clip_dx: clipped destination x location corresponding to start x
- *    clip_dy: clipped destination y location corresponding to start y
- *    clip_dw: clipped destination width
- *    clip_dh: clipped destination height
+ * @brief For internal scale by area sampling in 8 bits RGBA
+ *
+ * @param isi     scale info
+ * @param dest    destination image data
+ * @param dxx     destination x location corresponding to start x of source section
+ * @param dyy     destination y location corresponding to start y of source section
+ * @param dw      destination width
+ * @param dh      destination height
+ * @param dow     destination scanline width
+ * @param sow     source scanline width
+ * @param clip_dx clipped destination x location corresponding to start x
+ * @param clip_dy clipped destination y location corresponding to start y
+ * @param clip_dw clipped destination width
+ * @param clip_dh clipped destination height
  */
 void dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
                      int dxx, int dyy, int dw, int dh, int dow, int sow,
                      int clip_dx, int clip_dy, int clip_dw, int clip_dh);
 
 /**
- * For internal scale in 8 bits RGB, ignore the Alpha byte
-
- * Arguments:
- *    isi:  scale info
- *    dest: destination image data
- *    dxx:  destination x location corresponding to start x of source section
- *    dyy:  destination y location corresponding to start y of source section
- *    dw:   destination width
- *    dh:   destination height
- *    dow:  destination scanline width
- *    sow:  source scanline width
+ * @brief For internal scale in 8 bits RGB, ignore the Alpha byte
+ *
+ * @param isi  scale info
+ * @param dest destination image data
+ * @param dxx  destination x location corresponding to start x of source section
+ * @param dyy  destination y location corresponding to start y of source section
+ * @param dw   destination width
+ * @param dh   destination height
+ * @param dow  destination scanline width
+ * @param sow  source scanline width
  */
 void dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
                     int dxx, int dyy, int dw, int dh, int dow, int sow);
 
 /**
- * For internal scale by area sampling in 8 bits RGB, ignore the Alpha byte
- * Arguments:
- *    isi:     scale info
- *    dest:    destination image data
- *    dxx:     destination x location corresponding to start x of source section
- *    dyy:     destination y location corresponding to start y of source section
- *    dw:      destination width
- *    dh:      destination height
- *    dow:     destination scanline width
- *    sow:     source scanline width
- *    clip_dx: clipped destination x location corresponding to start x
- *    clip_dy: clipped destination y location corresponding to start y
- *    clip_dw: clipped destination width
- *    clip_dh: clipped destination height
+ * @brief For internal scale by area sampling in 8 bits RGB, ignore the Alpha byte
+ *
+ * @param isi     scale info
+ * @param dest    destination image data
+ * @param dxx     destination x location corresponding to start x of source section
+ * @param dyy     destination y location corresponding to start y of source section
+ * @param dw      destination width
+ * @param dh      destination height
+ * @param dow     destination scanline width
+ * @param sow     source scanline width
+ * @param clip_dx clipped destination x location corresponding to start x
+ * @param clip_dy clipped destination y location corresponding to start y
+ * @param clip_dw clipped destination width
+ * @param clip_dh clipped destination height
  */
 void dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
                     int dxx, int dyy, int dw, int dh, int dow, int sow,
                     int clip_dx, int clip_dy, int clip_dw, int clip_dh);
 
 /**
- * For internal scale in 16 bits RGBA
- * Arguments:
- *    isi:  scale info
- *    dest: destination image data
- *    dxx:  destination x location corresponding to start x of source section
- *    dyy:  destination y location corresponding to start y of source section
- *    dw:   destination width
- *    dh:   destination height
- *    dow:  destination scanline width
- *    sow:  source scanline width
+ * @brief For internal scale in 16 bits RGBA
+ *
+ * @param isi  scale info
+ * @param dest destination image data
+ * @param dxx  destination x location corresponding to start x of source section
+ * @param dyy  destination y location corresponding to start y of source section
+ * @param dw   destination width
+ * @param dh   destination height
+ * @param dow  destination scanline width
+ * @param sow  source scanline width
  */
 void dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
                        int dxx, int dyy, int dw, int dh,
                        int dow, int sow);
 
 /**
- * For internal scale by area sampling in 16 bits RGBA
- * Arguments:
- *    isi:     scale info
- *    dest:    destination image data
- *    dxx:     destination x location corresponding to start x of source section
- *    dyy:     destination y location corresponding to start y of source section
- *    dw:      destination width
- *    dh:      destination height
- *    dow:     destination scanline width
- *    sow:     source scanline width
- *    clip_dx: clipped destination x location corresponding to start x
- *    clip_dy: clipped destination y location corresponding to start y
- *    clip_dw: clipped destination width
- *    clip_dh: clipped destination height
+ * @brief For internal scale by area sampling in 16 bits RGBA
+ *
+ * @param isi     scale info
+ * @param dest    destination image data
+ * @param dxx     destination x location corresponding to start x of source section
+ * @param dyy     destination y location corresponding to start y of source section
+ * @param dw      destination width
+ * @param dh      destination height
+ * @param dow     destination scanline width
+ * @param sow     source scanline width
+ * @param clip_dx clipped destination x location corresponding to start x
+ * @param clip_dy clipped destination y location corresponding to start y
+ * @param clip_dw clipped destination width
+ * @param clip_dh clipped destination height
  */
 void dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
                        int dxx, int dyy, int dw, int dh,
@@ -273,36 +265,36 @@ void dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
                        int clip_dx, int clip_dy, int clip_dw, int clip_dh);
 
 /**
- * For internal scale in 16 bits RGB, ignore the Alpha byte
- * Arguments:
- *    isi:  scale info
- *    dest: destination image data
- *    dxx:  destination x location corresponding to start x of source section
- *    dyy:  destination y location corresponding to start y of source section
- *    dw:   destination width
- *    dh:   destination height
- *    dow:  destination scanline width
- *    sow:  source scanline width
+ * @brief For internal scale in 16 bits RGB, ignore the Alpha byte
+ *
+ * @param isi  scale info
+ * @param dest destination image data
+ * @param dxx  destination x location corresponding to start x of source section
+ * @param dyy  destination y location corresponding to start y of source section
+ * @param dw   destination width
+ * @param dh   destination height
+ * @param dow  destination scanline width
+ * @param sow  source scanline width
  */
 void dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
                       int dxx, int dyy, int dw, int dh,
                       int dow, int sow);
 
 /**
- * For internal scale by area sampling in 16 bits RGB, ignore the Alpha byte
- * Arguments:
- *    isi:     scale info
- *    dest:    destination image data
- *    dxx:     destination x location corresponding to start x of source section
- *    dyy:     destination y location corresponding to start y of source section
- *    dw:      destination width
- *    dh:      destination height
- *    dow:     destination scanline width
- *    sow:     source scanline width
- *    clip_dx: clipped destination x location corresponding to start x
- *    clip_dy: clipped destination y location corresponding to start y
- *    clip_dw: clipped destination width
- *    clip_dh: clipped destination height
+ * @brief For internal scale by area sampling in 16 bits RGB, ignore the Alpha byte
+ *
+ * @param isi     scale info
+ * @param dest    destination image data
+ * @param dxx     destination x location corresponding to start x of source section
+ * @param dyy     destination y location corresponding to start y of source section
+ * @param dw      destination width
+ * @param dh      destination height
+ * @param dow     destination scanline width
+ * @param sow     source scanline width
+ * @param clip_dx clipped destination x location corresponding to start x
+ * @param clip_dy clipped destination y location corresponding to start y
+ * @param clip_dw clipped destination width
+ * @param clip_dh clipped destination height
  */
 void dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
                       int dxx, int dyy, int dw, int dh,
@@ -331,7 +323,7 @@ DImg DImg::smoothScale(const QSize& destSize, Qt::AspectRatioMode aspectRatioMod
         return DImg();
     }
 
-    return smoothScaleClipped(scaleSize, QRect(QPoint(0, 0), scaleSize));
+    return smoothScaleClipped(scaleSize, QRect(QPoint(0, 0), scaleSize), true);
 }
 
 DImg DImg::smoothScale(int dw, int dh, Qt::AspectRatioMode aspectRatioMode) const
@@ -339,13 +331,13 @@ DImg DImg::smoothScale(int dw, int dh, Qt::AspectRatioMode aspectRatioMode) cons
     return smoothScale(QSize(dw, dh), aspectRatioMode);
 }
 
-DImg DImg::smoothScaleClipped(const QSize& destSize, const QRect& clip) const
+DImg DImg::smoothScaleClipped(const QSize& destSize, const QRect& clip, bool smooth) const
 {
     return DImg::smoothScaleClipped(destSize.width(), destSize.height(),
-                                    clip.x(), clip.y(), clip.width(), clip.height());
+                                    clip.x(), clip.y(), clip.width(), clip.height(), smooth);
 }
 
-DImg DImg::smoothScaleClipped(int dw, int dh, int clipx, int clipy, int clipw, int cliph) const
+DImg DImg::smoothScaleClipped(int dw, int dh, int clipx, int clipy, int clipw, int cliph, bool smooth) const
 {
     if ((dw <= 0) || (dh <= 0) || (clipw <= 0) || (cliph <= 0) || isNull())
     {
@@ -381,7 +373,7 @@ DImg DImg::smoothScaleClipped(int dw, int dh, int clipx, int clipy, int clipw, i
         }
     }
 
-    DImgScaleInfo* const scaleinfo = dimgCalcScaleInfo(*this, w, h, dw, dh, true);
+    DImgScaleInfo* const scaleinfo = dimgCalcScaleInfo(*this, w, h, dw, dh, true, smooth);
 
     DImg buffer(*this, clipw, cliph);
 
@@ -495,7 +487,7 @@ DImg DImg::smoothScaleSection(int sx, int sy,
 
     // calculate scaleinfo
 
-    DImgScaleInfo* const scaleinfo = dimgCalcScaleInfo(*this, sw, sh, dw, dh, true);
+    DImgScaleInfo* const scaleinfo = dimgCalcScaleInfo(*this, sw, sh, dw, dh, true, true);
 
     DImg buffer(*this, dw, dh);
 
@@ -548,10 +540,10 @@ DImg DImg::smoothScaleSection(int sx, int sy,
 // Code ported from Imlib2...
 // FIXME: replace with mRed, etc... These work on pointers to pixels, not pixel values
 
-#define A_VAL(p) ((unsigned char*)(p))[3]
-#define R_VAL(p) ((unsigned char*)(p))[2]
-#define G_VAL(p) ((unsigned char*)(p))[1]
-#define B_VAL(p) ((unsigned char*)(p))[0]
+#define A_VAL(p) (reinterpret_cast<unsigned char*>(p))[3]
+#define R_VAL(p) (reinterpret_cast<unsigned char*>(p))[2]
+#define G_VAL(p) (reinterpret_cast<unsigned char*>(p))[1]
+#define B_VAL(p) (reinterpret_cast<unsigned char*>(p))[0]
 
 #define INV_XAP  (256 - xapoints[x])
 #define XAP      (xapoints[x])
@@ -661,16 +653,18 @@ int* DImgScale::dimgCalcApoints(int s, int d, int up)
 DImgScaleInfo* DImgScale::dimgCalcScaleInfo(const DImg& img,
                                             int sw, int sh,
                                             int dw, int dh,
-                                            bool aa)
+                                            bool aa, bool smooth)
 {
     DImgScaleInfo* const isi = new DImgScaleInfo;
 
-    int scw = (ullong)dw * (ullong)img.width()  / (ullong)sw;
-    int sch = (ullong)dh * (ullong)img.height() / (ullong)sh;
+    int scw          = (ullong)dw * (ullong)img.width()  / (ullong)sw;
+    int sch          = (ullong)dh * (ullong)img.height() / (ullong)sh;
 
-    isi->xup_yup = (abs(dw) >= sw) + ((abs(dh) >= sh) << 1);
+    isi->xup_yup     = (abs(dw) >= sw) + ((abs(dh) >= sh) << 1);
 
-    isi->xpoints = dimgCalcXPoints(img.width(), scw);
+    isi->xpoints     = dimgCalcXPoints(img.width(), scw);
+
+    isi->scaleSmooth = smooth;
 
     if (img.sixteenBit())
     {
@@ -817,8 +811,8 @@ void DImgScale::dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
 {
     Q_UNUSED(dw);
     Q_UNUSED(dh);
-    uint* sptr = nullptr;
-    uint* dptr = nullptr;
+    uint* sptr        = nullptr;
+    uint* dptr        = nullptr;
     int x, y;
     uint** ypoints    = isi->ypoints;
     int* xpoints      = isi->xpoints;
@@ -843,14 +837,15 @@ void DImgScale::dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
             dptr = dest + (y - y_begin) * dow;
             sptr = ypoints[dyy + y];
 
-            if (YAP > 0)
+            if ((YAP > 0) && isi->scaleSmooth)
             {
                 for (x = x_begin ; x < x_end ; ++x)
                 {
                     int r, g, b, a;
                     uint* pix = nullptr;
 
-                    if (XAP > 0)
+                    // cppcheck-suppress knownConditionTrueFalse
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         int rr, gg, bb, aa;
 
@@ -918,7 +913,7 @@ void DImgScale::dimgScaleAARGBA(DImgScaleInfo* const isi, uint* const dest,
                 {
                     uint* pix = nullptr;
 
-                    if (XAP > 0)
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         int r, g, b, a;
 
@@ -1306,8 +1301,8 @@ void DImgScale::dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
 {
     Q_UNUSED(dw);
     Q_UNUSED(dh);
-    uint* sptr = nullptr;
-    uint* dptr = nullptr;
+    uint* sptr        = nullptr;
+    uint* dptr        = nullptr;
     int x, y;
     uint** ypoints    = isi->ypoints;
     int* xpoints      = isi->xpoints;
@@ -1332,14 +1327,16 @@ void DImgScale::dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
             dptr = dest + (y - y_begin) * dow;
             sptr = ypoints[dyy + y];
 
-            if (YAP > 0)
+            // cppcheck-suppress knownConditionTrueFalse
+            if ((YAP > 0) && isi->scaleSmooth)
             {
                 for (x = x_begin ; x < x_end ; ++x)
                 {
                     int   r = 0, g = 0, b = 0;
                     uint* pix = nullptr;
 
-                    if (XAP > 0)
+                    // cppcheck-suppress knownConditionTrueFalse
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         int rr = 0, gg = 0, bb = 0;
 
@@ -1399,7 +1396,7 @@ void DImgScale::dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
                 {
                     uint* pix = nullptr;
 
-                    if (XAP > 0)
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         int r = 0, g = 0, b = 0;
 
@@ -1734,10 +1731,10 @@ void DImgScale::dimgScaleAARGB(DImgScaleInfo* const isi, uint* const dest,
     }
 }
 
-#define A_VAL16(p) ((ushort*)(p))[3]
-#define R_VAL16(p) ((ushort*)(p))[2]
-#define G_VAL16(p) ((ushort*)(p))[1]
-#define B_VAL16(p) ((ushort*)(p))[0]
+#define A_VAL16(p) (reinterpret_cast<ushort*>(p))[3]
+#define R_VAL16(p) (reinterpret_cast<ushort*>(p))[2]
+#define G_VAL16(p) (reinterpret_cast<ushort*>(p))[1]
+#define B_VAL16(p) (reinterpret_cast<ushort*>(p))[0]
 
 void DImgScale::dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
                                  int dxx, int dyy,
@@ -1756,8 +1753,8 @@ void DImgScale::dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
 {
     Q_UNUSED(dw);
     Q_UNUSED(dh);
-    ullong* sptr = nullptr;
-    ullong* dptr = nullptr;
+    ullong* sptr      = nullptr;
+    ullong* dptr      = nullptr;
     int x, y;
     ullong** ypoints  = isi->ypoints16;
     int*     xpoints  = isi->xpoints;
@@ -1782,14 +1779,16 @@ void DImgScale::dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
             dptr = dest + (y - y_begin) * dow;
             sptr = ypoints[dyy + y];
 
-            if (YAP > 0)
+            // cppcheck-suppress knownConditionTrueFalse
+            if ((YAP > 0) && isi->scaleSmooth)
             {
                 for (x = x_begin ; x < x_end ; ++x)
                 {
                     llong r = 0, g = 0, b = 0;
                     ullong* pix = nullptr;
 
-                    if (XAP > 0)
+                    // cppcheck-suppress knownConditionTrueFalse
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         llong rr = 0, gg = 0, bb = 0;
 
@@ -1849,7 +1848,7 @@ void DImgScale::dimgScaleAARGB16(DImgScaleInfo* const isi, ullong* const dest,
                 {
                     ullong* pix = nullptr;
 
-                    if (XAP > 0)
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         llong r = 0, g = 0, b = 0;
 
@@ -2199,8 +2198,8 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
 {
     Q_UNUSED(dw);
     Q_UNUSED(dh);
-    ullong* sptr = nullptr;
-    ullong* dptr = nullptr;
+    ullong* sptr      = nullptr;
+    ullong* dptr      = nullptr;
     int x, y;
     ullong** ypoints  = isi->ypoints16;
     int* xpoints      = isi->xpoints;
@@ -2225,7 +2224,7 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
             dptr = dest + (y - y_begin) * dow;
             sptr = ypoints[dyy + y];
 
-            if (YAP > 0)
+            if ((YAP > 0) && isi->scaleSmooth)
             {
                 for (x = x_begin ; x < x_end ; ++x)
                 {
@@ -2233,7 +2232,8 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
                     llong rr, gg, bb, aa;
                     ullong* pix = nullptr;
 
-                    if (XAP > 0)
+                    // cppcheck-suppress knownConditionTrueFalse
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         pix  = ypoints[dyy + y] + xpoints[x];
                         r    = R_VAL16(pix) * INV_XAP;
@@ -2300,7 +2300,7 @@ void DImgScale::dimgScaleAARGBA16(DImgScaleInfo* const isi, ullong* const dest,
                     llong r, g, b, a;
                     ullong* pix = nullptr;
 
-                    if (XAP > 0)
+                    if ((XAP > 0) && isi->scaleSmooth)
                     {
                         pix = ypoints[dyy + y] + xpoints[x];
                         r   = R_VAL16(pix) * INV_XAP;
