@@ -6,7 +6,7 @@
  * Date        : 2005-05-25
  * Description : TextureFilter threaded image filter.
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TEXTURE_FILTER_H
-#define DIGIKAM_TEXTURE_FILTER_H
+#pragma once
 
 // Qt includes
 
@@ -78,5 +77,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TEXTURE_FILTER_H
