@@ -6,7 +6,7 @@
  * Date        : 2005-05-25
  * Description : Raindrop threaded image filter.
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -28,23 +28,25 @@
 #include <QDateTime>
 #include <QRect>
 #include <QtMath>
-#include <QtConcurrent>    // krazy:exclude=includes
+#include <QtConcurrentRun>
 
 // Local includes
 
 #include "dimg.h"
 #include "digikam_globals_p.h"      // For KF6::Ki18n deprecated
+#include "actionthreadbase.h"
 
 namespace Digikam
 {
 
 class Q_DECL_HIDDEN RainDropFilter::Private
 {
-
 public:
 
     Private() = default;
 
+public:
+
     int                   drop      = 80;
     int                   amount    = 150;
     int                   coeff     = 30;
@@ -138,6 +140,8 @@ void RainDropFilter::filterImage()
 
 void RainDropFilter::rainDropsImageMultithreaded(const Args& prm)
 {
+    ActionThreadBase::setCurrentThreadName(QLatin1String(__FUNCTION__));       // To customize thread name
+
     int  nRandSize;
     int  nRandX, nRandY;
     bool bResp      = false;
