@@ -7,7 +7,7 @@
  * Description : LDR ToneMapper <zynaddsubfx.sourceforge.net/other/tonemapping>.
  *
  * SPDX-FileCopyrightText: 2009      by Nasca Octavian Paul <zynaddsubfx at yahoo dot com>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -33,21 +33,8 @@ namespace Digikam
 {
 
 LocalContrastContainer::LocalContrastContainer()
-    : stretchContrast(true),
-      lowSaturation  (100),
-      highSaturation (100),
-      functionId     (0)
-{
-    for (int i = 0 ; i < TONEMAPPING_MAX_STAGES ; ++i)
-    {
-        stage[i].enabled = (i == 0);
-        stage[i].power   = 30.0;
-        stage[i].blur    = 80.0;
-    }
-}
-
-LocalContrastContainer::~LocalContrastContainer()
 {
+    stage[0].enabled = true;
 }
 
 double LocalContrastContainer::getPower(int nstage) const
