@@ -7,7 +7,7 @@
  * Description : Local Contrast settings view.
  *               LDR ToneMapper <zynaddsubfx.sourceforge.net/other/tonemapping>
  *
- * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -47,6 +47,7 @@
 #include "dnuminput.h"
 #include "digikam_debug.h"
 #include "dcombobox.h"
+#include "digikam_globals.h"
 
 namespace Digikam
 {
@@ -56,103 +57,60 @@ class Q_DECL_HIDDEN LocalContrastSettings::Private
 
 public:
 
-    explicit Private()
-      : stretchContrastCheck(nullptr),
-        label4              (nullptr),
-        label5              (nullptr),
-        label6              (nullptr),
-        label7              (nullptr),
-        label8              (nullptr),
-        label9              (nullptr),
-        label10             (nullptr),
-        label11             (nullptr),
-        lowSaturationInput  (nullptr),
-        highSaturationInput (nullptr),
-        functionInput       (nullptr),
-        powerInput1         (nullptr),
-        blurInput1          (nullptr),
-        powerInput2         (nullptr),
-        blurInput2          (nullptr),
-        powerInput3         (nullptr),
-        blurInput3          (nullptr),
-        powerInput4         (nullptr),
-        blurInput4          (nullptr),
-        expanderBox         (nullptr)
-    {
-    }
+    Private() = default;
 
-    static const QString  configLowSaturationEntry;
-    static const QString  configHighSaturationEntry;
-    static const QString  configPower1Entry;
-    static const QString  configBlur1Entry;
-    static const QString  configPower2Entry;
-    static const QString  configBlur2Entry;
-    static const QString  configPower3Entry;
-    static const QString  configBlur3Entry;
-    static const QString  configPower4Entry;
-    static const QString  configBlur4Entry;
-    static const QString  configStretchContrastEntry;
-    static const QString  configFastModeEntry;
-    static const QString  configStageOneEntry;
-    static const QString  configStageTwoEntry;
-    static const QString  configStageThreeEntry;
-    static const QString  configStageFourEntry;
-    static const QString  configFunctionInputEntry;
+    const QString configLowSaturationEntry      = QLatin1String("LowSaturation");
+    const QString configHighSaturationEntry     = QLatin1String("HighSaturation");
+    const QString configPower1Entry             = QLatin1String("Power1");
+    const QString configBlur1Entry              = QLatin1String("Blur1");
+    const QString configPower2Entry             = QLatin1String("Power2");
+    const QString configBlur2Entry              = QLatin1String("Blur2");
+    const QString configPower3Entry             = QLatin1String("Power3");
+    const QString configBlur3Entry              = QLatin1String("Blur3");
+    const QString configPower4Entry             = QLatin1String("Power4");
+    const QString configBlur4Entry              = QLatin1String("Blur4");
+    const QString configStretchContrastEntry    = QLatin1String("StretchContrast");
+    const QString configStageOneEntry           = QLatin1String("StageOne");
+    const QString configStageTwoEntry           = QLatin1String("StageTwo");
+    const QString configStageThreeEntry         = QLatin1String("StageThree");
+    const QString configStageFourEntry          = QLatin1String("StageFour");
+    const QString configFunctionInputEntry      = QLatin1String("FunctionInput");
 
-    QCheckBox*            stretchContrastCheck;
+    QCheckBox*            stretchContrastCheck  = nullptr;
 
-    QLabel*               label4;
-    QLabel*               label5;
-    QLabel*               label6;
-    QLabel*               label7;
-    QLabel*               label8;
-    QLabel*               label9;
-    QLabel*               label10;
-    QLabel*               label11;
+    QLabel*               label4                = nullptr;
+    QLabel*               label5                = nullptr;
+    QLabel*               label6                = nullptr;
+    QLabel*               label7                = nullptr;
+    QLabel*               label8                = nullptr;
+    QLabel*               label9                = nullptr;
+    QLabel*               label10               = nullptr;
+    QLabel*               label11               = nullptr;
 
-    DIntNumInput*         lowSaturationInput;
-    DIntNumInput*         highSaturationInput;
+    DIntNumInput*         lowSaturationInput    = nullptr;
+    DIntNumInput*         highSaturationInput   = nullptr;
 
-    DComboBox*            functionInput;
+    DComboBox*            functionInput         = nullptr;
 
-    DDoubleNumInput*      powerInput1;
-    DDoubleNumInput*      blurInput1;
-    DDoubleNumInput*      powerInput2;
-    DDoubleNumInput*      blurInput2;
-    DDoubleNumInput*      powerInput3;
-    DDoubleNumInput*      blurInput3;
-    DDoubleNumInput*      powerInput4;
-    DDoubleNumInput*      blurInput4;
+    DDoubleNumInput*      powerInput1           = nullptr;
+    DDoubleNumInput*      blurInput1            = nullptr;
+    DDoubleNumInput*      powerInput2           = nullptr;
+    DDoubleNumInput*      blurInput2            = nullptr;
+    DDoubleNumInput*      powerInput3           = nullptr;
+    DDoubleNumInput*      blurInput3            = nullptr;
+    DDoubleNumInput*      powerInput4           = nullptr;
+    DDoubleNumInput*      blurInput4            = nullptr;
 
-    DExpanderBox*         expanderBox;
+    DExpanderBox*         expanderBox           = nullptr;
 };
 
-const QString LocalContrastSettings::Private::configLowSaturationEntry(QLatin1String("LowSaturation"));
-const QString LocalContrastSettings::Private::configHighSaturationEntry(QLatin1String("HighSaturation"));
-const QString LocalContrastSettings::Private::configPower1Entry(QLatin1String("Power1"));
-const QString LocalContrastSettings::Private::configBlur1Entry(QLatin1String("Blur1"));
-const QString LocalContrastSettings::Private::configPower2Entry(QLatin1String("Power2"));
-const QString LocalContrastSettings::Private::configBlur2Entry(QLatin1String("Blur2"));
-const QString LocalContrastSettings::Private::configPower3Entry(QLatin1String("Power3"));
-const QString LocalContrastSettings::Private::configBlur3Entry(QLatin1String("Blur3"));
-const QString LocalContrastSettings::Private::configPower4Entry(QLatin1String("Power4"));
-const QString LocalContrastSettings::Private::configBlur4Entry(QLatin1String("Blur4"));
-const QString LocalContrastSettings::Private::configStretchContrastEntry(QLatin1String("StretchContrast"));
-const QString LocalContrastSettings::Private::configStageOneEntry(QLatin1String("StageOne"));
-const QString LocalContrastSettings::Private::configStageTwoEntry(QLatin1String("StageTwo"));
-const QString LocalContrastSettings::Private::configStageThreeEntry(QLatin1String("StageThree"));
-const QString LocalContrastSettings::Private::configStageFourEntry(QLatin1String("StageFour"));
-const QString LocalContrastSettings::Private::configFunctionInputEntry(QLatin1String("FunctionInput"));
-
 // --------------------------------------------------------
 
 LocalContrastSettings::LocalContrastSettings(QWidget* const parent)
     : QWidget(parent),
       d      (new Private)
 {
-    const int spacing        = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
-
+    const int spacing        = layoutSpacing();
     QGridLayout* const grid  = new QGridLayout(parent);
 
     QWidget* const firstPage = new QWidget();
