@@ -6,7 +6,7 @@
  * Date        : 2018-12-31
  * Description : digiKam plugin about dialog
  *
- * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -74,7 +74,7 @@ DPluginAboutDlg::DPluginAboutDlg(DPlugin* const tool, QWidget* const parent)
 
     QLabel* const header            = new QLabel(page);
     header->setWordWrap(true);
-    header->setText(QString::fromUtf8("<font size=\"5\">%1</font><br/>"
+    header->setText(QString::fromUtf8("<font size=\"5\">%1</font><br>"
                                       "<b>%2 %3</b>"
                                       "<p>%4</p>")
                     .arg(tool->name())
@@ -93,7 +93,7 @@ DPluginAboutDlg::DPluginAboutDlg(DPlugin* const tool, QWidget* const parent)
     details->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
 
     QString txtDetails = tool->details();
-    txtDetails.replace(QLatin1String("\n"), QLatin1String("<br/>"));
+    txtDetails.replace(QLatin1String("\n"), QLatin1String("<br>"));
     details->setText(txtDetails);
 
     tab->addTab(details, i18nc("@title", "Details"));
@@ -106,13 +106,14 @@ DPluginAboutDlg::DPluginAboutDlg(DPlugin* const tool, QWidget* const parent)
     authors->setFocusPolicy(Qt::NoFocus);
 
     QString alist;
+    const auto ats = tool->authors();
 
-    Q_FOREACH (const DPluginAuthor& auth, tool->authors())
+    for (const DPluginAuthor& auth : ats)
     {
         alist += QString::fromUtf8("<b>%1</b><ul>"
                                    "<li><i>%2</i></li>"
                                    "<li>%3</li>"
-                                   "<li>%4</li></ul><br/>")
+                                   "<li>%4</li></ul><br>")
                  .arg(auth.name)
                  .arg(auth.email)
                  .arg(auth.years)
@@ -180,8 +181,8 @@ DPluginAboutDlg::DPluginAboutDlg(DPlugin* const tool, QWidget* const parent)
     grid->setColumnStretch(1, 10);
     grid->setRowStretch(2, 10);
     grid->setContentsMargins(QMargins());
-    grid->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                          QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
+    grid->setSpacing(layoutSpacing());
+
 
     QVBoxLayout* const vbx = new QVBoxLayout(this);
     vbx->addWidget(page);
@@ -199,10 +200,6 @@ DPluginAboutDlg::DPluginAboutDlg(DPlugin* const tool, QWidget* const parent)
     resize(400, 500);
 }
 
-DPluginAboutDlg::~DPluginAboutDlg()
-{
-}
-
 void DPluginAboutDlg::slotOnlineHandbook()
 {
     openOnlineDocumentation(m_tool->handbookSection(), m_tool->handbookChapter(), m_tool->handbookReference());
