@@ -6,14 +6,13 @@
  * Date        : 2006-04-21
  * Description : video information container
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_VIDEO_INFO_CONTAINER_H
-#define DIGIKAM_VIDEO_INFO_CONTAINER_H
+#pragma once
 
 // Qt includes
 
@@ -33,8 +32,8 @@ class DIGIKAM_EXPORT VideoInfoContainer
 
 public:
 
-    explicit VideoInfoContainer();
-    ~VideoInfoContainer();
+    VideoInfoContainer()  = default;
+    ~VideoInfoContainer() = default;
 
     bool isEmpty()                                  const;
     bool isNull()                                   const;
@@ -59,5 +58,3 @@ DIGIKAM_EXPORT QDataStream& operator>>(QDataStream& ds, VideoInfoContainer& info
 DIGIKAM_EXPORT QDebug operator<<(QDebug dbg, const VideoInfoContainer& t);
 
 } // namespace Digikam
-
-#endif // DIGIKAM_VIDEO_INFO_CONTAINER_H
