@@ -7,15 +7,14 @@
  * Description : Captions, Tags, and Rating properties editor
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ITEM_DESC_EDIT_TAB_H
-#define DIGIKAM_ITEM_DESC_EDIT_TAB_H
+#pragma once
 
 // Qt includes
 
@@ -75,6 +74,7 @@ Q_SIGNALS:
 
     void signalProgressMessageChanged(const QString& actionDescription);
     void signalProgressValueChanged(float percent);
+    void signalRightSideBarBusy(bool busy);
     void signalProgressFinished();
 
     void signalPrevItem();
@@ -202,7 +202,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 
     friend class Private;
 
@@ -210,5 +210,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ITEM_DESC_EDIT_TAB_H
