@@ -6,7 +6,7 @@
  * Date        : 2006-20-12
  * Description : a view to embed QtMultimedia media player.
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,10 +17,12 @@
 // Qt includes
 
 #include <QApplication>
+#include <QActionGroup>
 #include <QVBoxLayout>
 #include <QMouseEvent>
 #include <QProxyStyle>
 #include <QPushButton>
+#include <QToolButton>
 #include <QFileInfo>
 #include <QToolBar>
 #include <QAction>
@@ -28,6 +30,7 @@
 #include <QLabel>
 #include <QFrame>
 #include <QStyle>
+#include <QMenu>
 #include <QTransform>
 #include <QGraphicsView>
 #include <QGraphicsScene>
@@ -35,6 +38,8 @@
 #include <QVideoSink>
 #include <QVideoFrame>
 #include <QAudioOutput>
+#include <QAudioDevice>
+#include <QMediaDevices>
 #include <QMediaMetaData>
 #include <QStandardPaths>
 
@@ -84,14 +89,20 @@ protected:
 
                 if (mplayer)
                 {
-                    if      ((mouseEvent->button() == Qt::LeftButton) &&
-                             ((singleClick && (event->type() == QEvent::MouseButtonPress)) ||
-                             (!singleClick && (event->type() == QEvent::MouseButtonDblClick))))
+                    if      (
+                             (mouseEvent->button() == Qt::LeftButton) &&
+                             (
+                              (singleClick  && (event->type() == QEvent::MouseButtonPress)) ||
+                              (!singleClick && (event->type() == QEvent::MouseButtonDblClick))
+                             )
+                            )
                     {
                         mplayer->slotEscapePressed();
                     }
-                    else if ((mouseEvent->button() == Qt::RightButton) &&
-                             (event->type() == QEvent::MouseButtonPress))
+                    else if (
+                             (mouseEvent->button() == Qt::RightButton) &&
+                             (event->type()        == QEvent::MouseButtonPress)
+                            )
                     {
                         mplayer->slotRotateVideo();
                     }
@@ -135,7 +146,7 @@ public:
 
 // --------------------------------------------------------
 
-class MediaPlayerView::Private
+class Q_DECL_HIDDEN MediaPlayerView::Private
 {
 
 public:
@@ -150,6 +161,8 @@ public:
 
     Private() = default;
 
+public:
+
     QFrame*              errorView          = nullptr;
     QFrame*              playerView         = nullptr;
 
@@ -157,8 +170,13 @@ public:
     QAction*             nextAction         = nullptr;
     QAction*             playAction         = nullptr;
     QAction*             grabAction         = nullptr;
+    QAction*             backAction         = nullptr;
+    QAction*             forwAction         = nullptr;
+
+    QToolButton*         rateButton         = nullptr;
 
     QPushButton*         loopPlay           = nullptr;
+    QPushButton*         speaker            = nullptr;
 
     QToolBar*            toolBar            = nullptr;
 
@@ -173,11 +191,17 @@ public:
     QSlider*             slider             = nullptr;
     QSlider*             volume             = nullptr;
     QLabel*              tlabel             = nullptr;
+
     QUrl                 currentItem;
 
     int                  videoOrientation   = 0;
     qint64               sliderTime         = 0;
 
+    const QUrl           dummyVideo         = QUrl::fromLocalFile(
+                                                  QStandardPaths::locate(
+                                                      QStandardPaths::GenericDataLocation,
+                                                      QLatin1String("digikam/data/video-digikam.mp4")));
+
 public:
 
     void adjustVideoSize()
@@ -187,14 +211,18 @@ public:
         QSizeF nativeSize    = videoItem->nativeSize();
         int mediaOrientation = videoMediaOrientation();
 
-        if ((nativeSize.width()  < 1.0) ||
-            (nativeSize.height() < 1.0))
+        if (
+            (nativeSize.width()  < 1.0) ||
+            (nativeSize.height() < 1.0)
+           )
         {
             return;
         }
 
-        if ((mediaOrientation == 90) ||
-            (mediaOrientation == 270))
+        if (
+            (mediaOrientation == 90) ||
+            (mediaOrientation == 270)
+           )
         {
             nativeSize.transpose();
         }
@@ -253,17 +281,66 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-    const int spacing      = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                  QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing      = layoutSpacing();
 
     d->prevAction          = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),
-                                         i18nc("go to previous image", "Back"),   this);
+                                         i18nc("go to previous image", "Back"),           this);
     d->nextAction          = new QAction(QIcon::fromTheme(QLatin1String("go-next")),
-                                         i18nc("go to next image", "Forward"),    this);
+                                         i18nc("go to next image", "Forward"),            this);
+    d->backAction          = new QAction(QIcon::fromTheme(QLatin1String("media-seek-backward")),
+                                         i18nc("video frame backward", "Frame Backward"), this);
     d->playAction          = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")),
-                                         i18nc("pause/play video", "Pause/Play"), this);
+                                         i18nc("pause/play video", "Pause/Play"),         this);
+    d->forwAction          = new QAction(QIcon::fromTheme(QLatin1String("media-seek-forward")),
+                                         i18nc("video frame forward", "Frame Forward"),   this);
     d->grabAction          = new QAction(QIcon::fromTheme(QLatin1String("view-preview")),
-                                         i18nc("capture video frame", "Capture"), this);
+                                         i18nc("capture video frame", "Capture"),         this);
+
+    d->rateButton          = new QToolButton(this);
+    d->rateButton->setToolTip(i18nc("@info", "Change video playback rate"));
+    d->rateButton->setIcon(QIcon::fromTheme(QLatin1String("player-time")));
+    d->rateButton->setPopupMode(QToolButton::InstantPopup);
+    d->rateButton->setArrowType(Qt::NoArrow);
+
+    QMenu* const rateMenu         = new QMenu(this);
+    QActionGroup* const rateGroup = new QActionGroup(this);
+
+    QAction* const rate05         = rateGroup->addAction(i18nc("video play rate", "0.5x"));
+    rate05->setCheckable(true);
+    rate05->setData(0.5);
+    QAction* const rate10         = rateGroup->addAction(i18nc("video play rate", "1.0x"));
+    rate10->setCheckable(true);
+    rate10->setData(1.0);
+    QAction* const rate15         = rateGroup->addAction(i18nc("video play rate", "1.5x"));
+    rate15->setCheckable(true);
+    rate15->setData(1.5);
+    QAction* const rate20         = rateGroup->addAction(i18nc("video play rate", "2.0x"));
+    rate20->setCheckable(true);
+    rate20->setData(2.0);
+    QAction* const rate25         = rateGroup->addAction(i18nc("video play rate", "2.5x"));
+    rate25->setCheckable(true);
+    rate25->setData(2.5);
+    QAction* const rate30         = rateGroup->addAction(i18nc("video play rate", "3.0x"));
+    rate30->setCheckable(true);
+    rate30->setData(3.0);
+    QAction* const rate40         = rateGroup->addAction(i18nc("video play rate", "4.0x"));
+    rate40->setCheckable(true);
+    rate40->setData(4.0);
+    QAction* const rate50         = rateGroup->addAction(i18nc("video play rate", "5.0x"));
+    rate50->setCheckable(true);
+    rate50->setData(5.0);
+
+    rate10->setChecked(true);
+
+    rateMenu->addAction(rate05);
+    rateMenu->addAction(rate10);
+    rateMenu->addAction(rate15);
+    rateMenu->addAction(rate20);
+    rateMenu->addAction(rate25);
+    rateMenu->addAction(rate30);
+    rateMenu->addAction(rate40);
+    rateMenu->addAction(rate50);
+    d->rateButton->setMenu(rateMenu);
 
     d->errorView           = new QFrame(this);
     QLabel* const errorMsg = new QLabel(i18n("An error has occurred with the media player..."), this);
@@ -287,6 +364,7 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     d->videoView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->videoView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->videoView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
+    d->videoView->setFrameShape(QFrame::NoFrame);
     d->videoItem  = new QGraphicsVideoItem();
     d->player     = new QMediaPlayer(this);
     d->audio      = new QAudioOutput;
@@ -313,8 +391,32 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     d->loopPlay->setFocusPolicy(Qt::NoFocus);
     d->loopPlay->setMinimumSize(22, 22);
     d->loopPlay->setCheckable(true);
-    QLabel* const spk = new QLabel(hbox);
-    spk->setPixmap(QIcon::fromTheme(QLatin1String("audio-volume-high")).pixmap(22, 22));
+
+    d->speaker        = new QPushButton(hbox);
+    d->speaker->setIcon(QIcon::fromTheme(QLatin1String("audio-volume-high")));
+    d->speaker->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
+    d->speaker->setFocusPolicy(Qt::NoFocus);
+    d->speaker->setMinimumSize(22, 22);
+
+#ifndef __clang_analyzer__
+
+    QMenu* const audioMenu         = new QMenu(this);
+    QActionGroup* const audioGroup = new QActionGroup(this);
+    const auto outputs             = QMediaDevices::audioOutputs();
+
+    for (const auto& device : outputs)
+    {
+        QAction* const action = audioGroup->addAction(device.description());
+        action->setCheckable(true);
+        action->setData(device.id());
+        action->setChecked(device.isDefault());
+        audioMenu->addAction(action);
+    }
+
+    d->speaker->setMenu(audioMenu);
+
+#endif
+
     d->volume         = new QSlider(Qt::Horizontal, hbox);
     d->volume->setRange(0, 100);
     d->volume->setValue(50);
@@ -334,7 +436,10 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     d->toolBar               = new QToolBar(this);
     d->toolBar->addAction(d->prevAction);
     d->toolBar->addAction(d->nextAction);
+    d->toolBar->addAction(d->backAction);
     d->toolBar->addAction(d->playAction);
+    d->toolBar->addAction(d->forwAction);
+    d->toolBar->addWidget(d->rateButton);
     d->toolBar->addAction(d->grabAction);
     d->toolBar->setStyleSheet(toolButtonStyleSheet());
 
@@ -362,9 +467,15 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     connect(d->nextAction, SIGNAL(triggered()),
             this, SIGNAL(signalNextItem()));
 
+    connect(d->backAction, SIGNAL(triggered()),
+            this, SLOT(slotFrameBackward()));
+
     connect(d->playAction, SIGNAL(triggered()),
             this, SLOT(slotPausePlay()));
 
+    connect(d->forwAction, SIGNAL(triggered()),
+            this, SLOT(slotFrameForward()));
+
     connect(d->grabAction, SIGNAL(triggered()),
             this, SLOT(slotCapture()));
 
@@ -397,11 +508,18 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
 
     connect(d->videoItem, SIGNAL(nativeSizeChanged(QSizeF)),
             this, SLOT(slotNativeSizeChanged()));
+
+    connect(rateMenu, SIGNAL(triggered(QAction*)),
+            this, SLOT(slotPlaybackRate(QAction*)));
+
+    connect(audioMenu, SIGNAL(triggered(QAction*)),
+            this, SLOT(slotAudioChanged(QAction*)));
 }
 
 MediaPlayerView::~MediaPlayerView()
 {
-    escapePreview();
+    d->player->stop();
+    d->player->setSource(QUrl());
 
     delete d;
 }
@@ -423,21 +541,16 @@ void MediaPlayerView::slotPlayerStateChanged(QMediaPlayer::PlaybackState newStat
     if (newState == QMediaPlayer::PlayingState)
     {
         d->playAction->setIcon(QIcon::fromTheme(QLatin1String("media-playback-pause")));
+
+        d->backAction->setEnabled(true);
+        d->forwAction->setEnabled(true);
     }
     else
     {
         d->playAction->setIcon(QIcon::fromTheme(QLatin1String("media-playback-start")));
 
         if (
-            (newState           == QMediaPlayer::StoppedState)  &&
-            (d->player->error() != QMediaPlayer::NoError)
-           )
-        {
-            setPreviewMode(Private::ErrorView);
-        }
-
-        if (
-            (newState                 == QMediaPlayer::StoppedState) &&
+            (newState                 == QMediaPlayer::StoppedState) ||
             (d->player->mediaStatus() == QMediaPlayer::EndOfMedia)
            )
         {
@@ -447,6 +560,9 @@ void MediaPlayerView::slotPlayerStateChanged(QMediaPlayer::PlaybackState newStat
             {
                 setPreviewMode(Private::ErrorView);
             }
+
+            d->backAction->setEnabled(false);
+            d->forwAction->setEnabled(false);
         }
     }
 }
@@ -462,9 +578,13 @@ void MediaPlayerView::slotMediaStatusChanged(QMediaPlayer::MediaStatus newStatus
 
         rotate     = (-rotate) + d->videoOrientation;
 
-        if ((rotate > 270) || (rotate < 0))
+        if      (rotate > 270)
         {
-            rotate = d->videoOrientation;
+            rotate = 0;
+        }
+        else if (rotate < 0)
+        {
+            rotate = 270;
         }
 
         d->setVideoItemOrientation(rotate);
@@ -478,9 +598,7 @@ void MediaPlayerView::slotMediaStatusChanged(QMediaPlayer::MediaStatus newStatus
 void MediaPlayerView::escapePreview()
 {
     d->player->stop();
-    QString dummy = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                           QLatin1String("digikam/data/video-digikam.mp4"));
-    d->player->setSource(QUrl::fromLocalFile(dummy));
+    d->player->setSource(d->dummyVideo);
 }
 
 void MediaPlayerView::slotThemeChanged()
@@ -501,7 +619,7 @@ void MediaPlayerView::slotEscapePressed()
 
 void MediaPlayerView::slotRotateVideo()
 {
-    if (d->player->isPlaying())
+    if (d->player->playbackState() != QMediaPlayer::StoppedState)
     {
         int orientation = 0;
 
@@ -541,12 +659,59 @@ void MediaPlayerView::slotPausePlay()
     if (!d->player->isPlaying())
     {
         d->player->play();
+
         return;
     }
 
     d->player->pause();
 }
 
+void MediaPlayerView::slotFrameBackward()
+{
+    if (d->player->isPlaying())
+    {
+        d->player->pause();
+
+        return;
+    }
+
+    QVariant frameRateVar = d->player->metaData().value(QMediaMetaData::VideoFrameRate);
+
+    if (frameRateVar.isValid())
+    {
+        double frameRate = frameRateVar.toDouble();
+
+        if (frameRate > 0.0)
+        {
+           double frame = 1000.0 / frameRate;
+           d->player->setPosition(d->player->position() - frame);
+        }
+    }
+}
+
+void MediaPlayerView::slotFrameForward()
+{
+    if (d->player->isPlaying())
+    {
+        d->player->pause();
+
+        return;
+    }
+
+    QVariant frameRateVar = d->player->metaData().value(QMediaMetaData::VideoFrameRate);
+
+    if (frameRateVar.isValid())
+    {
+        double frameRate = frameRateVar.toDouble();
+
+        if (frameRate > 0.0)
+        {
+           double frame = 1000.0 / frameRate;
+           d->player->setPosition(d->player->position() + frame);
+        }
+    }
+}
+
 void MediaPlayerView::slotCapture()
 {
     if (d->player->playbackState() != QMediaPlayer::StoppedState)
@@ -559,6 +724,36 @@ void MediaPlayerView::slotCapture()
         if (!image.isNull() && d->currentItem.isValid())
         {
             QFileInfo info(d->currentItem.toLocalFile());
+            QDateTime dateTime;
+
+            if (d->iface)
+            {
+                DItemInfo dinfo(d->iface->itemInfo(d->currentItem));
+                dateTime = dinfo.dateTime();
+            }
+            else
+            {
+                QScopedPointer<DMetadata> meta2(new DMetadata);
+
+                if (meta2->load(d->currentItem.toLocalFile()))
+                {
+                    dateTime = meta2->getItemDateTime();
+                }
+            }
+
+            if (dateTime.isValid())
+            {
+                dateTime = dateTime.addMSecs(capturePosition);
+            }
+            else
+            {
+                dateTime = QDateTime::currentDateTime();
+            }
+
+            QTransform transform;
+            transform.rotate(d->videoOrientation);
+            image = image.transformed(transform);
+
             QString tempPath = QString::fromUtf8("%1/%2-%3.digikamtempfile.jpg")
                               .arg(info.path())
                               .arg(info.baseName())
@@ -570,44 +765,9 @@ void MediaPlayerView::slotCapture()
 
                 if (meta->load(tempPath))
                 {
-                    QDateTime dateTime;
-                    MetaEngine::ImageOrientation orientation = MetaEngine::ORIENTATION_NORMAL;
-
-                    if (d->iface)
-                    {
-                        DItemInfo dinfo(d->iface->itemInfo(d->currentItem));
-
-                        dateTime    = dinfo.dateTime();
-                        orientation = (MetaEngine::ImageOrientation)dinfo.orientation();
-                    }
-                    else
-                    {
-                        QScopedPointer<DMetadata> meta2(new DMetadata);
-
-                        if (meta2->load(d->currentItem.toLocalFile()))
-                        {
-                            dateTime    = meta2->getItemDateTime();
-                            orientation = meta2->getItemOrientation();
-                        }
-                    }
-
-                    if (dateTime.isValid())
-                    {
-                        dateTime = dateTime.addMSecs(capturePosition);
-                    }
-                    else
-                    {
-                        dateTime = QDateTime::currentDateTime();
-                    }
-
-                    if (orientation == MetaEngine::ORIENTATION_UNSPECIFIED)
-                    {
-                        orientation = MetaEngine::ORIENTATION_NORMAL;
-                    }
-
+                    meta->setItemOrientation(MetaEngine::ORIENTATION_NORMAL);
                     meta->setImageDateTime(dateTime, true);
                     meta->setItemDimensions(image.size());
-                    meta->setItemOrientation(orientation);
                     meta->save(tempPath, true);
                 }
 
@@ -724,8 +884,10 @@ void MediaPlayerView::setCurrentItem(const QUrl& url, bool hasPrevious, bool has
 
 void MediaPlayerView::slotPositionChanged(qint64 position)
 {
-    if ((d->sliderTime < position)       &&
-        ((d->sliderTime + 100) > position))
+    if (
+        (d->sliderTime < position)       &&
+        ((d->sliderTime + 100) > position)
+       )
     {
         return;
     }
@@ -778,6 +940,31 @@ void MediaPlayerView::slotDurationChanged(qint64 duration)
     d->slider->setRange(0, max);
 }
 
+void MediaPlayerView::slotPlaybackRate(QAction* action)
+{
+    if (action)
+    {
+        d->player->setPlaybackRate(action->data().toReal());
+    }
+}
+
+void MediaPlayerView::slotAudioChanged(QAction* action)
+{
+    if (action)
+    {
+        const auto outputs = QMediaDevices::audioOutputs();
+
+        for (const auto& device : outputs)
+        {
+            if (action->data().toByteArray() == device.id())
+            {
+                d->audio->setDevice(device);
+                break;
+            }
+        }
+    }
+}
+
 void MediaPlayerView::slotPosition(int position)
 {
     if (d->player->isSeekable())
