@@ -6,14 +6,13 @@
  * Date        : 2008-12-23
  * Description : a widget to select between system font or a custom font.
  *
- * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DFONT_SELECT_H
-#define DIGIKAM_DFONT_SELECT_H
+#pragma once
 
 // Qt includes
 
@@ -66,9 +65,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DFONT_SELECT_H
