@@ -7,7 +7,7 @@
  * Description : Managing visibility state with animations
  *
  * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -165,7 +165,7 @@ public:
     void moveTo(AnimationControl* const other, QObject* const item);
     void moveAllTo(AnimationControl* const other);
 
-    bool hasItem(QObject* const o) const;
+    bool hasItem(QObject* const o)                                            const;
     bool hasVisibleItems(ItemVisibilityController::IncludeFadingOutMode mode) const;
 
     void transitionToVisible(bool show, bool immediately = false);
@@ -231,7 +231,7 @@ void AnimationControl::clear()
     m_animation      = nullptr;
     m_animationGroup = nullptr; // the same pointer as animation
 
-    Q_FOREACH (QObject* const item, m_items)
+    for (QObject* const item : std::as_const(m_items))
     {
         disconnect(item);
     }
@@ -280,6 +280,7 @@ void AnimationControl::moveToGroup()
     }
 }
 
+// cppcheck-suppress constParameterPointer
 void AnimationControl::addItem(QAbstractAnimation* const anim, QObject* const item)
 {
     // Either there is no group but now for the first time two items,
@@ -299,6 +300,7 @@ void AnimationControl::addItem(QAbstractAnimation* const anim, QObject* const it
     m_items << item;
 }
 
+// cppcheck-suppress constParameterPointer
 QAbstractAnimation* AnimationControl::takeItem(QObject* const item)
 {
     int index = m_items.indexOf(item);
@@ -336,12 +338,13 @@ void AnimationControl::moveTo(AnimationControl* const other, QObject* const item
 
 void AnimationControl::moveAllTo(AnimationControl* const other)
 {
-    Q_FOREACH (QObject* const item, m_items)
+    for (QObject* const item : std::as_const(m_items))
     {
         moveTo(other, item);
     }
 }
 
+// cppcheck-suppress constParameterPointer
 bool AnimationControl::hasItem(QObject* const o) const
 {
     return m_items.contains(o);
@@ -369,9 +372,9 @@ bool AnimationControl::hasVisibleItems(ItemVisibilityController::IncludeFadingOu
 
 void AnimationControl::setVisibleProperty(bool value)
 {
-    Q_FOREACH (QObject* const o, m_items)
+    for (QObject* const item : std::as_const(m_items))
     {
-        o->setProperty("visible", value);
+        item->setProperty("visible", value);
     }
 }
 
@@ -540,7 +543,7 @@ public:
 
 AnimationControl* ItemVisibilityController::Private::findInChildren(QObject* const item) const
 {
-    Q_FOREACH (AnimationControl* const child, childControls)
+    for (AnimationControl* const child : std::as_const(childControls))
     {
         if (child->hasItem(item))
         {   // cppcheck-suppress useStlAlgorithm
@@ -589,7 +592,7 @@ void ItemVisibilityController::Private::cleanupChildren(QAbstractAnimation* cons
         }
         else if ((child->m_animation == finishedAnimation) && (child->m_situation == AnimationControl::RemovingControl))
         {
-            Q_FOREACH (QObject* const item, child->m_items)
+            for (QObject* const item : std::as_const(child->m_items))
             {
                 Q_EMIT q->hiddenAndRemoved(item);
             }
@@ -615,7 +618,7 @@ void ItemVisibilityController::Private::setVisible(bool v, bool immediately)
         control->transitionToVisible(shallBeShown && visible, immediately);
     }
 
-    Q_FOREACH (AnimationControl* const child, childControls)
+    for (AnimationControl* const child : std::as_const(childControls))
     {
         if (child->m_situation == AnimationControl::IndependentControl)
         {
@@ -666,7 +669,7 @@ QPropertyAnimation* ItemVisibilityController::createAnimation(QObject*)
     return anim;
 }
 
-void ItemVisibilityController::addItem(QObject* item)
+void ItemVisibilityController::addItem(QObject* const item)
 {
     if (!item)
     {
@@ -688,7 +691,7 @@ void ItemVisibilityController::addItem(QObject* item)
     d->control->addItem(anim, item);
 }
 
-void ItemVisibilityController::removeItem(QObject* item)
+void ItemVisibilityController::removeItem(QObject* const item)
 {
     if (!item || !d->control)
     {
@@ -720,7 +723,7 @@ void ItemVisibilityController::clear()
         d->control->clear();
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         child->clear();
     }
@@ -739,7 +742,7 @@ QList<QObject*> ItemVisibilityController::items() const
         items = d->control->m_items;
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         // cppcheck-suppress useStlAlgorithm
         items += child->m_items;
@@ -757,7 +760,7 @@ QList<QObject*> ItemVisibilityController::visibleItems(IncludeFadingOutMode mode
         items = d->control->m_items;
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         if (child->hasVisibleItems(mode))
         {
@@ -791,7 +794,7 @@ bool ItemVisibilityController::hasVisibleItems(IncludeFadingOutMode mode) const
         return true;
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         if (child->hasVisibleItems(mode))
         {   // cppcheck-suppress useStlAlgorithm
@@ -811,7 +814,7 @@ void ItemVisibilityController::setEasingCurve(const QEasingCurve& easing)
         d->control->setEasingCurve(easing);
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         child->setEasingCurve(easing);
     }
@@ -826,7 +829,7 @@ void ItemVisibilityController::setAnimationDuration(int msecs)
         d->control->setAnimationDuration(msecs);
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         child->setAnimationDuration(msecs);
     }
@@ -925,17 +928,17 @@ void ItemVisibilityController::animationFinished()
         Q_EMIT propertiesAssigned(d->control->m_state == Visible);
     }
 
-    Q_FOREACH (AnimationControl* const child, d->childControls)
+    for (AnimationControl* const child : std::as_const(d->childControls))
     {
         if (child->m_animation == animation)
         {
             child->animationFinished();
 
-            Q_FOREACH (QObject* const item, child->m_items)
+            for (QObject* const item : std::as_const(child->m_items))
             {
                 if (d->control)
                 {
-                    Q_EMIT propertiesAssigned(item, (d->control->m_state == Visible));
+                    Q_EMIT propertiesAssignedToItem(item, (d->control->m_state == Visible));
                 }
             }
         }
