@@ -8,14 +8,13 @@
  *               in file dialog preview.
  *
  * SPDX-FileCopyrightText: 2006-2007 by Francisco J. Cruz <fj dot cruz at supercable dot es>
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ICC_PREVIEW_WIDGET_H
-#define DIGIKAM_ICC_PREVIEW_WIDGET_H
+#pragma once
 
 // Qt includes
 
@@ -39,18 +38,16 @@ class DIGIKAM_EXPORT ICCPreviewWidget : public QScrollArea
 public:
 
     explicit ICCPreviewWidget(QWidget* const parent = nullptr);
-    ~ICCPreviewWidget() override;
+    ~ICCPreviewWidget() override = default;
 
 public Q_SLOTS:
 
     void slotShowPreview(const QUrl& url);
     void slotClearPreview();
 
-private :
+private:
 
-    ICCProfileWidget* m_iccProfileWidget;
+    ICCProfileWidget* m_iccProfileWidget = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ICC_PREVIEW_WIDGET_H
