@@ -7,7 +7,7 @@
  * Description : Qt item view for images
  *
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -306,7 +306,7 @@ void ItemViewCategorized::setSelectedIndexes(const QList<QModelIndex>& indexes)
 
     QItemSelection mySelection;
 
-    Q_FOREACH (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : std::as_const(indexes))
     {
         mySelection.select(index, index);
     }
@@ -434,7 +434,7 @@ void ItemViewCategorized::slotClicked(const QModelIndex& index)
 {
     if (d->currentMouseEvent)
     {
-        Q_EMIT clicked(d->currentMouseEvent, index);
+        Q_EMIT signalClicked(d->currentMouseEvent, index);
     }
 }
 
@@ -442,7 +442,7 @@ void ItemViewCategorized::slotEntered(const QModelIndex& index)
 {
     if (d->currentMouseEvent)
     {
-        Q_EMIT entered(d->currentMouseEvent, index);
+        Q_EMIT signalEntered(d->currentMouseEvent, index);
     }
 }
 
@@ -453,7 +453,7 @@ void ItemViewCategorized::reset()
     // FIXME : Emitting this causes a crash importstackedview, because the model is not yet set.
     //         atm there's a check against null models though.
 
-    Q_EMIT selectionChanged();
+    Q_EMIT itemSelectionChanged();
     Q_EMIT selectionCleared();
 
     d->ensureInitialSelectedItem = d->initialSelectedItem;
@@ -468,7 +468,7 @@ void ItemViewCategorized::selectionChanged(const QItemSelection& selectedItems,
 {
     DCategorizedView::selectionChanged(selectedItems, deselectedItems);
 
-    Q_EMIT selectionChanged();
+    Q_EMIT itemSelectionChanged();
 
     if (!selectionModel()->hasSelection())
     {
@@ -492,14 +492,13 @@ void ItemViewCategorized::rowsRemoved(const QModelIndex& parent, int start, int
 {
     DCategorizedView::rowsRemoved(parent, start, end);
 
-    if (d->scrollCurrentToCenter)
+    if (
+        d->scrollCurrentToCenter                                ||
+        !viewport()->rect().intersects(visualRect(currentIndex()))
+       )
     {
         scrollTo(currentIndex(), QAbstractItemView::PositionAtCenter);
     }
-    else
-    {
-        scrollTo(currentIndex(), QAbstractItemView::PositionAtTop);
-    }
 }
 
 void ItemViewCategorized::rowsAboutToBeRemoved(const QModelIndex& parent, int start, int end)
@@ -1014,7 +1013,7 @@ void ItemViewCategorized::keyPressEvent(QKeyEvent* event)
     {
         const QModelIndexList indexList = selModel->selectedIndexes();
 
-        Q_FOREACH (const QModelIndex& index, indexList)
+        for (const QModelIndex& index : std::as_const(indexList))
         {
             Q_EMIT itemTriggered(itemForIndex(index));
         }
