@@ -28,11 +28,7 @@ namespace Digikam
 {
 
 ItemViewHoverButton::ItemViewHoverButton(QAbstractItemView* const view)
-    : QAbstractButton(view->viewport()),
-      m_isHovered       (false),
-      m_fadingValue     (0),
-      m_icon            (),
-      m_fadingTimeLine  (nullptr)
+    : QAbstractButton(view->viewport())
 {
     m_fadingTimeLine = new QTimeLine(600, this);
     m_fadingTimeLine->setFrameRange(0, 255);
@@ -95,11 +91,16 @@ void ItemViewHoverButton::setVisible(bool visible)
     }
 }
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
 void ItemViewHoverButton::enterEvent(QEnterEvent* event)
+
 #else
+
 void ItemViewHoverButton::enterEvent(QEvent* event)
+
 #endif
+
 {
     QAbstractButton::enterEvent(event);
 
@@ -219,3 +220,5 @@ void ItemViewHoverButton::stopFading()
 }
 
 } // namespace Digikam
+
+#include "moc_itemviewhoverbutton.cpp"
