@@ -7,15 +7,14 @@
  * Description : A widget to host settings as expander box
  *
  * SPDX-FileCopyrightText: 2008-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2010 by Manuel Viet <contact at 13zenrv dot fr>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DEXPANDER_BOX_H
-#define DIGIKAM_DEXPANDER_BOX_H
+#pragma once
 
 // Qt includes
 
@@ -82,12 +81,12 @@ private:
     // Disabled methods from QLabel
     QString text() const { return QString(); }; ///< Use adjustedText() instead.
     void setText(const QString&) {};            ///< Use setAdjustedText(text) instead.
-    void clear() {};                            ///< Use setdjustedText(QString()) instead.
+    void clear()                 {};            ///< Use setdjustedText(QString()) instead.
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // -------------------------------------------------------------------------
@@ -150,7 +149,7 @@ class DIGIKAM_EXPORT DArrowClickLabel : public QWidget
 public:
 
     explicit DArrowClickLabel(QWidget* const parent = nullptr);
-    ~DArrowClickLabel()                               override;
+    ~DArrowClickLabel()                               override = default;
 
     void setArrowType(Qt::ArrowType arrowType);
     Qt::ArrowType arrowType()                   const;
@@ -169,9 +168,9 @@ protected:
 
 protected:
 
-    Qt::ArrowType m_arrowType;
-    int           m_size;
-    int           m_margin;
+    Qt::ArrowType m_arrowType   = Qt::DownArrow;
+    int           m_size        = 8;
+    int           m_margin      = 2;
 };
 
 // -------------------------------------------------------------------------
@@ -197,6 +196,10 @@ public:
     void setText(const QString& txt);
     QString text()              const;
 
+    void setButtonVisible(bool b);
+    bool buttonIsVisible()      const;
+    void setButtonIcon(const QIcon& icon);
+
     void setIcon(const QIcon &icon);
     QIcon icon()                const;
 
@@ -213,10 +216,12 @@ Q_SIGNALS:
 
     void signalExpanded(bool);
     void signalToggled(bool);
+    void signalButtonPressed();
 
 private Q_SLOTS:
 
     void slotToggleContainer();
+    void slotUpdateIcon();
 
 private:
 
@@ -226,7 +231,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // -------------------------------------------------------------------------
@@ -280,6 +285,10 @@ public:
     void setItemIcon(int index, const QIcon &icon);
     QIcon itemIcon(int index)                   const;
 
+    void setButtonVisible(int index, bool b);
+    bool buttonIsVisible(int index)             const;
+    void setButtonIcon(int index, const QIcon& icon);
+
     void setItemToolTip(int index, const QString& tip);
     QString itemToolTip(int index)              const;
 
@@ -304,16 +313,18 @@ Q_SIGNALS:
 
     void signalItemExpanded(int index, bool b);
     void signalItemToggled(int index, bool b);
+    void signalItemButtonPressed(int index);
 
 private Q_SLOTS:
 
     void slotItemExpanded(bool b);
     void slotItemToggled(bool b);
+    void slotItemButtonPressed();
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 // -------------------------------------------------------------------------
@@ -325,7 +336,7 @@ class DIGIKAM_EXPORT DExpanderBoxExclusive : public DExpanderBox
 public:
 
     explicit DExpanderBoxExclusive(QWidget* const parent = nullptr);
-    ~DExpanderBoxExclusive()   override;
+    ~DExpanderBoxExclusive()   override = default;;
 
     /**
      * Show one expander open at most
@@ -339,9 +350,7 @@ private Q_SLOTS:
 
 private:
 
-    bool m_toolbox;
+    bool m_toolbox  = true;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DEXPANDER_BOX_H
