@@ -6,14 +6,13 @@
  * Date        : 2021-08-27
  * Description : Showfoto folder view bookmarks list
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOWFOTO_FOLDER_VIEW_BOOKMARK_LIST_H
-#define SHOWFOTO_FOLDER_VIEW_BOOKMARK_LIST_H
+#pragma once
 
 // Qt includes
 
@@ -81,9 +80,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace ShowFoto
-
-#endif // SHOWFOTO_FOLDER_VIEW_BOOKMARK_LIST_H
