@@ -6,15 +6,14 @@
  * Date        : 2017-05-06
  * Description : interface to item information for Showfoto
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOWFOTO_INFO_IFACE_H
-#define SHOWFOTO_INFO_IFACE_H
+#pragma once
 
 // Local includes
 
@@ -32,12 +31,11 @@ class ShowfotoInfoIface : public DMetaInfoIface
 public:
 
     explicit ShowfotoInfoIface(QObject* const parent,
-                               const QList<QUrl>& lst);
-    ~ShowfotoInfoIface()               override;
+                               const QList<QUrl>& lst,
+                               const QUrl& currentActive);
+    ~ShowfotoInfoIface()               override = default;
 
     void openSetupPage(SetupPage page) override;
 };
 
 } // namespace ShowFoto
-
-#endif // SHOWFOTO_INFO_IFACE_H
