@@ -6,18 +6,9 @@
  * Date        : 2021-09-27
  * Description : Showfoto stack view favorites
  *
- * Copyright (C) 2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,7 +30,9 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QTextStream>
-#include <QTextCodec>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    #include <QTextCodec>
+#endif
 
 // KDE includes
 
@@ -61,31 +54,25 @@ class Q_DECL_HIDDEN ShowfotoStackViewFavorites::Private
 {
 public:
 
-    explicit Private()
-      : addBtn         (nullptr),
-        fldBtn         (nullptr),
-        delBtn         (nullptr),
-        edtBtn         (nullptr),
-        favoritesList  (nullptr),
-        topFavorites   (nullptr),
-        sidebar        (nullptr),
-        favoritesFilter(nullptr)
-    {
-        file = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/favorites.xml");
-    }
+    Private() = default;
 
 public:
 
     QList<QAction*>                 actionsList;                    ///< Used to shared actions with list-view context menu.
-    QToolButton*                    addBtn;                         ///< Add favorite button.
-    QToolButton*                    fldBtn;                         ///< Add sub-folder button.
-    QToolButton*                    delBtn;                         ///< Delete item button.
-    QToolButton*                    edtBtn;                         ///< Edit item button.
-    ShowfotoStackViewFavoriteList*  favoritesList;
-    ShowfotoStackViewFavoriteItem*  topFavorites;                   ///< Top-level parent of all favorite items.
-    ShowfotoStackViewSideBar*       sidebar;
-    QString                         file;                           ///< Path to store favorites XML data file.
-    SearchTextBar*                  favoritesFilter;
+    QToolButton*                    addBtn          = nullptr;      ///< Add favorite button.
+    QToolButton*                    fldBtn          = nullptr;      ///< Add sub-folder button.
+    QToolButton*                    delBtn          = nullptr;      ///< Delete item button.
+    QToolButton*                    edtBtn          = nullptr;      ///< Edit item button.
+    ShowfotoStackViewFavoriteList*  favoritesList   = nullptr;
+    ShowfotoStackViewFavoriteItem*  topFavorites    = nullptr;      ///< Top-level parent of all favorite items.
+    ShowfotoStackViewSideBar*       sidebar         = nullptr;
+    SearchTextBar*                  favoritesFilter = nullptr;
+
+    /**
+     * Path to store favorites XML data file.
+     */
+    QString                         file            = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) +
+                                                      QLatin1String("/favorites.xml");
 };
 
 ShowfotoStackViewFavorites::ShowfotoStackViewFavorites(ShowfotoStackViewSideBar* const sidebar)
@@ -191,15 +178,15 @@ ShowfotoStackViewFavorites::ShowfotoStackViewFavorites(ShowfotoStackViewSideBar*
 
     grid->setRowStretch(1, 10);
     grid->setColumnStretch(1, 10);
-    grid->setContentsMargins(0, 0, 0, 0);
+    grid->setContentsMargins(QMargins());
 
     // --------------------------------------------------------
 
     connect(d->favoritesList, SIGNAL(itemSelectionChanged()),
             this, SLOT(slotItemSelectionChanged()));
 
-    connect(d->favoritesList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
-            this, SLOT(slotFavoriteDoubleClicked(QTreeWidgetItem*)));
+    connect(d->favoritesList, SIGNAL(itemActivated(QTreeWidgetItem*,int)),
+            this, SLOT(slotFavoriteActivated(QTreeWidgetItem*)));
 
     connect(d->sidebar, SIGNAL(signalAddFavorite()),
             this, SLOT(slotAddFavorite()));
@@ -207,7 +194,7 @@ ShowfotoStackViewFavorites::ShowfotoStackViewFavorites(ShowfotoStackViewSideBar*
     connect(d->favoritesList, SIGNAL(signalAddFavorite()),
             this, SLOT(slotAddFavorite()));
 
-    connect(d->favoritesList, SIGNAL(signalAddFavorite(QList<QUrl>,QUrl)),
+    connect(d->favoritesList, SIGNAL(signalAddFavoriteList(QList<QUrl>,QUrl)),
             this, SLOT(slotAddFavorite(QList<QUrl>,QUrl)));
 
     connect(d->favoritesList, SIGNAL(signalLoadContentsFromFiles(QStringList,QString)),
@@ -227,7 +214,7 @@ ShowfotoStackViewFavorites::~ShowfotoStackViewFavorites()
 
 QAction* ShowfotoStackViewFavorites::toolBarAction(const QString& name) const
 {
-    foreach (QAction* const act, d->actionsList)
+    for (QAction* const act : std::as_const(d->actionsList))
     {
         if (act && (act->objectName() == name))
         {
@@ -363,7 +350,7 @@ void ShowfotoStackViewFavorites::slotDelItem()
         return;
     }
 
-    if (QMessageBox::question(this, i18nc("@title: window", "Confirm Item Deletion"),
+    if (QMessageBox::question(this, i18nc("@title:window", "Confirm Item Deletion"),
                               i18nc("@info", "Are you sure you want to remove the item \"%1\"\n"
                                              "and all nested items if any?", fitem->name()))
             != QMessageBox::Yes)
@@ -487,13 +474,13 @@ void ShowfotoStackViewFavorites::slotItemSelectionChanged()
     d->edtBtn->setEnabled(b);
 }
 
-void ShowfotoStackViewFavorites::slotFavoriteDoubleClicked(QTreeWidgetItem* item)
+void ShowfotoStackViewFavorites::slotFavoriteActivated(QTreeWidgetItem* item)
 {
     ShowfotoStackViewFavoriteItem* const fvitem = dynamic_cast<ShowfotoStackViewFavoriteItem*>(item);
 
     if (fvitem && (fvitem->favoriteType() == ShowfotoStackViewFavoriteItem::FavoriteItem))
     {
-        emit signalLoadContentsFromFiles(fvitem->urlsToPaths(), fvitem->currentUrl().toLocalFile());
+        Q_EMIT signalLoadContentsFromFiles(fvitem->urlsToPaths(), fvitem->currentUrl().toLocalFile());
     }
 }
 
@@ -559,7 +546,9 @@ bool ShowfotoStackViewFavorites::saveSettings()
             QDomElement urls = doc.createElement(QLatin1String("UrlsList"));
             elem.appendChild(urls);
 
-            foreach (const QUrl& url, item->urls())
+            const auto curls = item->urls();
+
+            for (const QUrl& url : curls)
             {
                 QDomElement e = doc.createElement(QLatin1String("Url"));
                 e.setAttribute(QLatin1String("value"), url.toLocalFile());
@@ -584,7 +573,17 @@ bool ShowfotoStackViewFavorites::saveSettings()
     }
 
     QTextStream stream(&file);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    stream.setEncoding(QStringConverter::Utf8);
+
+#else
+
     stream.setCodec(QTextCodec::codecForName("UTF-8"));
+
+#endif
+
     stream.setAutoDetectUnicode(true);
     stream << doc.toString();
     file.close();
@@ -761,7 +760,7 @@ bool ShowfotoStackViewFavorites::readSettings()
                         {
                             if (!fitem->urls().isEmpty())
                             {
-                                curr = fitem->urls().first().toLocalFile();
+                                curr = fitem->urls().constFirst().toLocalFile();
                             }
                             else
                             {
@@ -797,3 +796,5 @@ void ShowfotoStackViewFavorites::slotSearchResult(int found)
 }
 
 } // namespace ShowFoto
+
+#include "moc_showfotostackviewfavorites.cpp"
