@@ -7,14 +7,13 @@
  * Description : Qt model view for Showfoto item - the delegate
  *
  * SPDX-FileCopyrightText: 2013      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * SPDX-FileCopyrightText: 2013-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2013-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOW_FOTO_DELEGATE_H
-#define SHOW_FOTO_DELEGATE_H
+#pragma once
 
 // Qt includes
 
@@ -50,8 +49,6 @@ public:
 
     int calculatethumbSizeToFit(int ws);
 
-    void setSpacing(int spacing)                                                                       override;
-    void setDefaultViewOptions(const QStyleOptionViewItem& option)                                     override;
     bool acceptsToolTip(const QPoint& pos, const QRect& visualRect,
                         const QModelIndex& index, QRect* tooltipRect = nullptr)                  const override;
     bool acceptsActivation(const QPoint& pos, const QRect& visualRect,
@@ -106,7 +103,6 @@ protected:
 
     virtual QPixmap thumbnailPixmap(const QModelIndex& index)                                    const;
 
-    void invalidatePaintingCache()                                                                     override;
     void updateSizeRectsAndPixmaps()                                                                   override;
 
 protected Q_SLOTS:
@@ -187,5 +183,3 @@ private:
 };
 
 } // namespace ShowFoto
-
-#endif // SHOW_FOTO_DELEGATE_H
