@@ -112,6 +112,7 @@ do
         {                                                                                                   \
             /* Adding item to listView by creating an item and passing listView as parent */                \
             FindDuplicatesAlbumItem* const item = new FindDuplicatesAlbumItem(&w, salbum);                  \
+            item->waitForCalculate();                                                                       \
             salbum->setExtraData(this, item);                                                               \
             const auto id   = salbum->title().toLongLong();                                                 \
             ItemInfo info(id);                                                                              \
@@ -141,7 +142,9 @@ void HaarIfaceTest::initTestCase()
 
     // Update collection path, because this is hardcoded
 
-    for (const auto& col : CollectionManager::instance()->allLocations())
+    const auto locs = CollectionManager::instance()->allLocations();
+
+    for (const auto& col : locs)
     {
         CollectionManager::instance()->removeLocation(col);
     }
@@ -170,7 +173,7 @@ void HaarIfaceTest::startSqlite(const QDir& dbDir)
 
     if (!QSqlDatabase::isDriverAvailable(DbEngineParameters::SQLiteDatabaseType()))
     {
-        QWARN("Qt SQlite plugin is missing.");
+        qWarning() << QLatin1String("Qt SQlite plugin is missing.");
         return;
     }
 
@@ -213,7 +216,7 @@ void HaarIfaceTest::stopSql()
 // Collection/potentialDuplicates/subfolder/subsubfolder/LargerSmaler.png
 
 /*!
- * \brief HaarIfaceTest::testOriginal
+ * @brief HaarIfaceTest::testOriginal
  * Original behaviour
  */
 void HaarIfaceTest::testOriginal()
@@ -224,7 +227,7 @@ void HaarIfaceTest::testOriginal()
     AlbumList searchAlbums       = all;
     AlbumList referenceAlbums;
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES
 
     QCOMPARE(references.count(), 3);
@@ -255,7 +258,7 @@ void HaarIfaceTest::testOriginal()
 }
 
 /*!
- * \brief HaarIfaceTest::testExcludeRefSelectpotentialDuplicates
+ * @brief HaarIfaceTest::testExcludeRefSelectpotentialDuplicates
  * The selected folder shall not be used as reference
  */
 void HaarIfaceTest::testExcludeRefSelectpotentialDuplicates()
@@ -267,7 +270,7 @@ void HaarIfaceTest::testExcludeRefSelectpotentialDuplicates()
     AlbumList searchAlbums = all;
     AlbumList referenceAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -279,7 +282,7 @@ void HaarIfaceTest::testExcludeRefSelectpotentialDuplicates()
         }
     }
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES
 
     QCOMPARE(references.count(), 3);
@@ -310,7 +313,7 @@ void HaarIfaceTest::testExcludeRefSelectpotentialDuplicates()
 }
 
 /*!
- * \brief HaarIfaceTest::testPreferFolderSelectpotentialDuplicates
+ * @brief HaarIfaceTest::testPreferFolderSelectpotentialDuplicates
  * The selected folder is preferred as reference
  */
 void HaarIfaceTest::testPreferFolderSelectpotentialDuplicates()
@@ -322,7 +325,7 @@ void HaarIfaceTest::testPreferFolderSelectpotentialDuplicates()
     AlbumList searchAlbums = all;
     AlbumList referenceAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -334,7 +337,7 @@ void HaarIfaceTest::testPreferFolderSelectpotentialDuplicates()
         }
     }
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES;
 
     QCOMPARE(references.count(), 3);
@@ -370,7 +373,7 @@ void HaarIfaceTest::testPreferNewerCreationDate()
     AlbumList searchAlbums = all;
     AlbumList referenceAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -382,7 +385,7 @@ void HaarIfaceTest::testPreferNewerCreationDate()
         }
     }
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES;
 
     QCOMPARE(references.count(), 3);
@@ -412,7 +415,7 @@ void HaarIfaceTest::testPreferNewerModificationDate()
     AlbumList searchAlbums = all;
     AlbumList referenceAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -424,7 +427,7 @@ void HaarIfaceTest::testPreferNewerModificationDate()
         }
     }
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES;
 
     QCOMPARE(references.count(), 3);
@@ -457,7 +460,7 @@ void HaarIfaceTest::testPreferFolderWhole()
     AlbumList searchAlbums       = all;
     AlbumList referenceAlbums    = all;
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES;
 
     QCOMPARE(references.count(), 3);
@@ -475,12 +478,12 @@ void HaarIfaceTest::testPreferFolderWhole()
 }
 
 /*!
- * \brief HaarIfaceTest::testReferenceFolderNotSelected
+ * @brief HaarIfaceTest::testReferenceFolderNotSelected
  * The reference folder is not in the search folders.
- * But neverthless the folder shall be checked, otherwise
- * the duplicates get not found. The Duplicatesfinder will merge interally the
+ * But nevertheless the folder shall be checked, otherwise
+ * the duplicates aren't found. The Duplicatesfinder will merge internally the
  * two album lists
- * The oposite that the folder is in both lists will be tested above, so
+ * The opposite that the folder is in both lists will be tested above, so
  * no extra test is needed.
  */
 void HaarIfaceTest::testReferenceFolderNotSelected()
@@ -491,7 +494,7 @@ void HaarIfaceTest::testReferenceFolderNotSelected()
     AlbumList tags; // empty
     AlbumList searchAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -509,7 +512,7 @@ void HaarIfaceTest::testReferenceFolderNotSelected()
 
     AlbumList referenceAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -521,7 +524,7 @@ void HaarIfaceTest::testReferenceFolderNotSelected()
         }
     }
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES;
 
     QCOMPARE(references.count(), 3);
@@ -552,7 +555,7 @@ void HaarIfaceTest::testReferenceFolderNotSelected()
 }
 
 /*!
- * \brief HaarIfaceTest::testReferenceFolderNotSelected
+ * @brief HaarIfaceTest::testReferenceFolderNotSelected
  * Similar test to testReferenceFolderNotSelected(), but with the difference,
  * "Collection/potentialDuplicates/subfolder" is in both, the reference and in the search albums
  */
@@ -565,7 +568,7 @@ void HaarIfaceTest::testReferenceFolderPartlySelected()
     AlbumList tags; // empty
     AlbumList searchAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -589,7 +592,7 @@ void HaarIfaceTest::testReferenceFolderPartlySelected()
 
     AlbumList referenceAlbums;
 
-    for (auto* const a : all)
+    for (auto* const a : std::as_const(all))
     {
         const auto& path = static_cast<PAlbum*>(a)->albumPath();
 
@@ -601,7 +604,7 @@ void HaarIfaceTest::testReferenceFolderPartlySelected()
         }
     }
 
-    QHash<ImagePath, QList<ItemInfo>> references;
+    QHash<ImagePath, QList<ItemInfo> > references;
     START_SEARCHING_DUPLICATES;
 
     QCOMPARE(references.count(), 3);
