@@ -6,20 +6,12 @@
  * Date        : 2011-03-22
  * Description : a MediaWiki C++ interface
  *
- * Copyright (C) 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2011      by Alexandre Mendes <alex dot mendes1988 at gmail dot com>
- * Copyright (C) 2011      by Hormiere Guillaume <hormiere dot guillaume at gmail dot com>
- * Copyright (C) 2011      by Manuel Campomanes <campomanes dot manuel at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011      by Alexandre Mendes <alex dot mendes1988 at gmail dot com>
+ * SPDX-FileCopyrightText: 2011      by Hormiere Guillaume <hormiere dot guillaume at gmail dot com>
+ * SPDX-FileCopyrightText: 2011      by Manuel Campomanes <campomanes dot manuel at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -73,7 +65,7 @@ public Q_SLOTS:
     {
         editCount++;
         this->CaptchaQuestion = captcha;
-        emit captchaSignal(this->CaptchaAnswer);
+        Q_EMIT captchaSignal(this->CaptchaAnswer);
     }
 
 private Q_SLOTS:
@@ -82,19 +74,19 @@ private Q_SLOTS:
     {
         editCount            = 0;
         this->m_mediaWiki    = new Iface(QUrl(QStringLiteral("http://127.0.0.1:12566")));           // krazy:exclude=insecurenet
-        this->m_infoScenario = QStringLiteral("<api><query><pages><page pageid=\"27697087\" ns=\"0\" title=\"API\" touched=\"2010-11-25T13:59:03Z\" lastrevid=\"367741756\" counter=\"0\" length=\"70\" redirect=\"\" starttimestamp=\"2010-11-25T16:14:51Z\" edittoken=\"cecded1f35005d22904a35cc7b736e18+\\\" talkid=\"5477418\" fullurl=\"https://en.wikipedia.org/wiki/API\" editurl=\"https://en.wikipedia.org/w/index.php?title=API&action=edit\" ><protection /></page></pages></query></api>");
+        this->m_infoScenario = QStringLiteral("<api><query><pages><page pageid=\"27697087\" ns=\"0\" title=\"API\" touched=\"2010-11-25T13:59:03Z\" lastrevid=\"367741756\" counter=\"0\" length=\"70\" redirect=\"\" starttimestamp=\"2010-11-25T16:14:51Z\" talkid=\"5477418\" fullurl=\"https://en.wikipedia.org/wiki/API\" editurl=\"https://en.wikipedia.org/w/index.php?title=API&action=edit\" ><protection /><tokens csrftoken=\"cecded1f35005d22904a35cc7b736e18+\\\" /></page></pages></query></api>");
     }
 
     void editSetters()
     {
         QFETCH(QString, request);
-        QFETCH(QString, senario);
+        QFETCH(QString, scenario);
         QFETCH(Edit*, job);
 
         editCount = 0;
         FakeServer fakeserver;
         fakeserver.setScenario(m_infoScenario);
-        fakeserver.addScenario(senario);
+        fakeserver.addScenario(scenario);
         fakeserver.startAndWait();
 
         connect(job, SIGNAL(result(KJob*)),
@@ -111,7 +103,7 @@ private Q_SLOTS:
     void editSetters_data()
     {
         QTest::addColumn<QString>("request");
-        QTest::addColumn<QString>("senario");
+        QTest::addColumn<QString>("scenario");
         QTest::addColumn<Edit*>("job");
 
         Edit* const e1 = new Edit( *m_mediaWiki, nullptr);
@@ -335,22 +327,22 @@ private Q_SLOTS:
         QTest::newRow("No text")
                 << QStringLiteral("<api><error code=\"notext\" info=\"\" /> </api>")
                 << int(Edit::TextMissing);
-        QTest::newRow("Invalide section")
+        QTest::newRow("Invalid section")
                 << QStringLiteral("<api><error code=\"invalidsection\" info=\"\" /> </api>")
                 << int(Edit::InvalidSection);
-        QTest::newRow("Invalide section")
+        QTest::newRow("Invalid section")
                 << QStringLiteral("<api><error code=\"invalidsection\" info=\"\" /> </api>")
                 << int(Edit::InvalidSection);
         QTest::newRow("Protected Title")
                 << QStringLiteral("<api><error code=\"protectedtitle\" info=\"\" /> </api>")
                 << int(Edit::TitleProtected);
-        QTest::newRow("Cant Create")
+        QTest::newRow("Cannot Create")
                 << QStringLiteral("<api><error code=\"cantcreate\" info=\"\" /> </api>")
                 << int(Edit::CreatePagePermissionMissing);
-        QTest::newRow("Cant Create Anonymous")
+        QTest::newRow("Cannot Create Anonymous")
                 << QStringLiteral("<api><error code=\"cantcreate-anon\" info=\"\" /> </api>")
                 << int(Edit::AnonymousCreatePagePermissionMissing);
-        QTest::newRow("Cant Create Anonymous")
+        QTest::newRow("Cannot Create Anonymous")
                 << QStringLiteral("<api><error code=\"cantcreate-anon\" info=\"\" /> </api>")
                 << int(Edit::AnonymousCreatePagePermissionMissing);
         QTest::newRow("Article Duplication")
@@ -403,12 +395,12 @@ private Q_SLOTS:
         FakeServer fakeserver;
 
         this->request = QStringLiteral("/?format=xml&action=edit&basetimestamp=2008-03-20T17:26:39Z&md5=4d184ec6e8fe61abccb8ff62c4583cd0&section=new&starttimestamp=2008-03-27T21:15:39Z&summary=Hello%20World&text=Hello%20everyone!&title=Talk:Main%20Page&token=cecded1f35005d22904a35cc7b736e18+%5C");
-        QString senario(QStringLiteral("<api><edit result=\"Failure\"><captcha type=\"math\" mime=\"text/tex\" id=\"509895952\" question=\"36 + 4 = \" /></edit></api>"));
+        QString scenario(QStringLiteral("<api><edit result=\"Failure\"><captcha type=\"math\" mime=\"text/tex\" id=\"509895952\" question=\"36 + 4 = \" /></edit></api>"));
 
         fakeserver.setScenario(m_infoScenario);
-        fakeserver.addScenario(senario);
-        senario = QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>");
-        fakeserver.addScenario(senario);
+        fakeserver.addScenario(scenario);
+        scenario = QStringLiteral("<api><edit result=\"Success\" pageid=\"12\" title=\"Talk:Main Page\" oldrevid=\"465\" newrevid=\"471\" /></api>");
+        fakeserver.addScenario(scenario);
         fakeserver.startAndWait();
 
         Edit edit( *m_mediaWiki, nullptr);
