@@ -6,7 +6,7 @@
  * Date        : 2011-12-28
  * Description : a class to manage Raw to Png conversion using threads
  *
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2014 by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -41,10 +41,10 @@ public:
 
 Q_SIGNALS:
 
-    void starting(const QUrl& url);
-    void finished(const QUrl& url);
-    void failed(const QUrl& url, const QString& err);
-    void progress(const QUrl& url, int percent);
+    void signalStarting(const QUrl& url);
+    void signalFinished(const QUrl& url);
+    void signalFailed(const QUrl& url, const QString& err);
+    void signalProgress(const QUrl& url, int percent);
 
 private Q_SLOTS:
 
