@@ -7,18 +7,18 @@
  * Description : Face recognition benchmarker
  *
  * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RECOGNITION_BENCH_MARKER_H
-#define DIGIKAM_RECOGNITION_BENCH_MARKER_H
+#pragma once
 
 // Local includes
 
 #include "facepipeline_p.h"
+#include "facialrecognition_wrapper.h"
 
 namespace Digikam
 {
@@ -46,22 +46,20 @@ protected:
     {
     public:
 
-        Statistics();
+        Statistics() = default;
 
     public:
 
-        int knownFaces;
-        int correctlyRecognized;
+        int knownFaces          = 0;
+        int correctlyRecognized = 0;
     };
 
 protected:
 
     QMap<int, Statistics>        results;
-
-    FacePipeline::Private* const d;
     FacialRecognitionWrapper     recognizer;
+
+    FacePipeline::Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_RECOGNITION_BENCH_MARKER_H
