@@ -197,7 +197,7 @@ RegionFrameItem* FaceGroup::closestItem(const QPointF& p, qreal* const manhattan
         if (
             !closestItem             ||
             (distance < minDistance) ||
-            ((distance == 0) && (p - r.center()).manhattanLength() < minCenterDistance)
+            ((distance == 0) && ((p - r.center()).manhattanLength()) < minCenterDistance)
            )
         {
             closestItem = item;
@@ -301,8 +301,10 @@ void FaceGroup::load()
 {
     d->exifRotate = (
                         MetaEngineSettings::instance()->settings().exifRotate            ||
-                        ((d->view->previewItem()->image().detectedFormat() == DImg::RAW) &&
-                         !d->view->previewItem()->image().attribute(QLatin1String("fromRawEmbeddedPreview")).toBool())
+                        (
+                         (d->view->previewItem()->image().detectedFormat() == DImg::RAW) &&
+                         !d->view->previewItem()->image().attribute(QLatin1String("fromRawEmbeddedPreview")).toBool()
+                        )
                     );
 
     if (d->info.isNull())
@@ -351,7 +353,7 @@ void FaceGroup::clear()
 
 void FaceGroup::rejectAll()
 {
-    FaceUtils().removeAllFaces(d->info.id());
+    d->newEditPipeline->removeAllFaces(d->info);
     clear();
 }
 
@@ -460,10 +462,6 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const
     {
         int tagId = 0;
 
-        // Apply a modified region.
-
-        face.setRegion(currentRegion);
-
         if      (action.shallAssignTag())
         {
             tagId = action.tagId();
@@ -496,7 +494,7 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const
             return;
         }
 
-        face = d->newEditPipeline->confirmFace(d->info, face, tagId, true);
+        face = d->newEditPipeline->confirmFace(d->info, face, currentRegion, tagId, true);
         item->setFace(face);
 
         item->switchMode(AssignNameWidget::ConfirmedMode);
@@ -556,20 +554,10 @@ void FaceGroup::slotIgnored(const ItemInfo&, const QVariant& faceIdentifier)
 
         TagRegion currentRegion(faceRect);
 
-        if (face.region() != currentRegion)
-        {
-            DImg preview(d->view->previewItem()->image().copy());
+        face = d->newEditPipeline->editRegion(d->info, face,
+                                              currentRegion,
+                                              FaceTags::ignoredPersonTagId(), false);
 
-            if (!d->exifRotate)
-            {
-                preview.rotateAndFlip(d->info.orientation());
-            }
-
-            face = d->newEditPipeline->editRegion(d->info, face, currentRegion, preview, false);
-        }
-
-        face = d->newEditPipeline->editTag(d->info, face,
-                                           FaceTags::ignoredPersonTagId());
         item->setFace(face);
         item->switchMode(AssignNameWidget::IgnoredMode);
 
@@ -698,13 +686,6 @@ void FaceGroup::applyItemGeometryChanges()
         return;
     }
 
-    DImg preview(d->view->previewItem()->image().copy());
-
-    if (!d->exifRotate)
-    {
-        preview.rotateAndFlip(d->info.orientation());
-    }
-
     for (FaceItem* const item : std::as_const(d->items))
     {
         if (item->face().isNull())
@@ -727,9 +708,7 @@ void FaceGroup::applyItemGeometryChanges()
         {
             d->newEditPipeline->editRegion(d->info,
                                            item->face(),
-                                           currentRegion,
-                                           preview,
-                                           false);
+                                           currentRegion, -1, false);
         }
     }
 }
