@@ -6,14 +6,13 @@
  * Date        : 2009-28-04
  * Description : first run assistant dialog
  *
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DATABASE_PAGE_H
-#define DIGIKAM_DATABASE_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DATABASE_PAGE_H
