@@ -5,9 +5,10 @@
  *
  * Date        : 2023-05-15
  * Description : geolocation engine based on Marble.
+ *               (c) 2007-2022 Marble Team
+ *               https://invent.kde.org/education/marble/-/raw/master/data/credits_authors.html
  *
- * SPDX-FileCopyrightText: 2007-2022 Marble Team
- * SPDX-FileCopyrightText: 2023-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2023-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
@@ -186,7 +187,7 @@ StackedTile* MergedLayerDecorator::Private::createTile(const QVector<QSharedPoin
         if (blending)
         {
 
-            qCDebug(DIGIKAM_MARBLE_LOG) << Q_FUNC_INFO << "blending";
+            qCDebug(DIGIKAM_GEOENGINE_LOG) << Q_FUNC_INFO << "blending";
 
             if (resultImage.isNull())
             {
@@ -198,7 +199,7 @@ StackedTile* MergedLayerDecorator::Private::createTile(const QVector<QSharedPoin
 
         else
         {
-            qCDebug(DIGIKAM_MARBLE_LOG) << Q_FUNC_INFO << "no blending defined => copying top over bottom image";
+            qCDebug(DIGIKAM_GEOENGINE_LOG) << Q_FUNC_INFO << "no blending defined => copying top over bottom image";
 
             if (withConversion)
             {
@@ -335,14 +336,14 @@ StackedTile* MergedLayerDecorator::loadTile(const TileId& stackedTileId)
         const TileId tileId(layer->sourceDir(), stackedTileId.zoomLevel(),
                             stackedTileId.x(), stackedTileId.y());
 
-        qCDebug(DIGIKAM_MARBLE_LOG) << Q_FUNC_INFO << layer->sourceDir() << tileId << layer->tileSize() << layer->fileFormat();
+        qCDebug(DIGIKAM_GEOENGINE_LOG) << Q_FUNC_INFO << layer->sourceDir() << tileId << layer->tileSize() << layer->fileFormat();
 
         // Blending (how to merge the images into an only image)
         const Blending* blending = d->m_blendingFactory.findBlending(layer->blending());
 
         if (blending == nullptr && !layer->blending().isEmpty())
         {
-            qCDebug(DIGIKAM_MARBLE_LOG) << Q_FUNC_INFO << "could not find blending" << layer->blending();
+            qCDebug(DIGIKAM_GEOENGINE_LOG) << Q_FUNC_INFO << "could not find blending" << layer->blending();
         }
 
         const GeoSceneTextureTileDataset* const textureLayer = static_cast<const GeoSceneTextureTileDataset*>(layer);
@@ -569,17 +570,33 @@ void MergedLayerDecorator::Private::paintTileId(QImage* tileImage, const TileId&
     if (((qreal)(id.x()) / 2 == id.x() / 2 && (qreal)(id.y()) / 2 == id.y() / 2)
         || ((qreal)(id.x()) / 2 != id.x() / 2 && (qreal)(id.y()) / 2 != id.y() / 2)
        )
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 6, 0))
+
+    {
+        foreground.fromString(QString::fromUtf8("#FFFFFF"));
+        background.fromString(QString::fromUtf8("#000000"));
+    }
+    else
+    {
+        foreground.fromString(QString::fromUtf8("#000000"));
+        background.fromString(QString::fromUtf8("#FFFFFF"));
+    }
+
+#else
+
     {
         foreground.setNamedColor(QString::fromUtf8("#FFFFFF"));
         background.setNamedColor(QString::fromUtf8("#000000"));
     }
-
     else
     {
         foreground.setNamedColor(QString::fromUtf8("#000000"));
         background.setNamedColor(QString::fromUtf8("#FFFFFF"));
     }
 
+#endif
+
     int   strokeWidth = 10;
     QPen  testPen(foreground);
     testPen.setWidth(strokeWidth);
@@ -663,7 +680,7 @@ QVector<const GeoSceneTextureTileDataset*> MergedLayerDecorator::Private::findRe
     return result;
 }
 
-// TODO: This should likely go into a math class Q_DECL_HIDDEN in the future ...
+// TODO: This should likely go into a math class in the future ...
 
 int MergedLayerDecorator::Private::maxDivisor(int maximum, int fullLength)
 {
@@ -676,7 +693,7 @@ int MergedLayerDecorator::Private::maxDivisor(int maximum, int fullLength)
     for (int it = 1; it <= maximum; ++it)
     {
         // The optimum is the interval which results in the least amount
-        // supporting points taking into account the rest which can't
+        // supporting points taking into account the rest which cannot
         // get used for interpolation.
         int nEval = fullLength / it + fullLength % it;
 
