@@ -6,7 +6,7 @@
  * Date        : 2007-09-06
  * Description : a dialog to control camera capture.
  *
- * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -40,23 +40,16 @@ class Q_DECL_HIDDEN CaptureDlg::Private
 {
 public:
 
-    explicit Private()
-      : stopPreview  (false),
-        timer        (nullptr),
-        buttons      (nullptr),
-        controller   (nullptr),
-        captureWidget(nullptr)
-    {
-    }
+    Private() = default;
 
-    bool              stopPreview;
+    bool              stopPreview   = false;
 
-    QTimer*           timer;
-    QDialogButtonBox* buttons;
+    QTimer*           timer         = nullptr;
+    QDialogButtonBox* buttons       = nullptr;
 
-    CameraController* controller;
+    CameraController* controller    = nullptr;
 
-    CaptureWidget*    captureWidget;
+    CaptureWidget*    captureWidget = nullptr;
 };
 
 CaptureDlg::CaptureDlg(QWidget* const parent,
@@ -81,12 +74,6 @@ CaptureDlg::CaptureDlg(QWidget* const parent,
     vbx->addWidget(d->buttons);
     setLayout(vbx);
 
-    KConfigGroup group     = KSharedConfig::openConfig()->group(QLatin1String("Capture Tool Dialog"));
-
-    winId();
-    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
-    resize(windowHandle()->size());
-
     // -------------------------------------------------------------
 
     connect(d->buttons->button(QDialogButtonBox::Ok), SIGNAL(clicked()),
@@ -124,6 +111,17 @@ CaptureDlg::~CaptureDlg()
     delete d;
 }
 
+void CaptureDlg::showEvent(QShowEvent* e)
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(QLatin1String("Capture Tool Dialog"));
+
+    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size());
+
+    QDialog::showEvent(e);
+}
+
 void CaptureDlg::closeEvent(QCloseEvent* e)
 {
     d->stopPreview = true;
@@ -133,7 +131,9 @@ void CaptureDlg::closeEvent(QCloseEvent* e)
         d->timer->stop();
     }
 
-    KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Capture Tool Dialog"));
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(QLatin1String("Capture Tool Dialog"));
+
     DXmlGuiWindow::saveWindowSize(windowHandle(), group);
 
     e->accept();
