@@ -6,14 +6,13 @@
  * Date        : 2008-11-27
  * Description : a view to show Batch Tool Settings.
  *
- * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_TOOL_SETTINGS_VIEW_H
-#define DIGIKAM_BQM_TOOL_SETTINGS_VIEW_H
+#pragma once
 
 // Qt includes
 
@@ -62,9 +61,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_BQM_TOOL_SETTINGS_VIEW_H
