@@ -6,7 +6,7 @@
  * Date        : 2007-11-15
  * Description : widget item delegate for setup collection view
  *
- * SPDX-FileCopyrightText: 2015-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2015-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2007-2008 by Rafael Fernández López <ereslibre at kde dot org>
  * SPDX-FileCopyrightText: 2008      by Kevin Ottens <ervin at kde dot org>
  *
@@ -115,7 +115,7 @@ QList<QWidget*> DWItemDelegatePool::findWidgets(const QPersistentModelIndex& idx
         result                = d->delegate->createItemWidgets(index);
         d->usedWidgets[index] = result;
 
-        Q_FOREACH (QWidget* const widget, result)
+        for (QWidget* const widget : std::as_const(result))
         {
             d->widgetInIndex[widget] = index;
             widget->setParent(d->delegate->d->itemView->viewport());
@@ -126,14 +126,14 @@ QList<QWidget*> DWItemDelegatePool::findWidgets(const QPersistentModelIndex& idx
 
     if (updateWidgets == UpdateWidgets)
     {
-        Q_FOREACH (QWidget* const widget, result)
+        for (QWidget* const widget : std::as_const(result))
         {
             widget->setVisible(true);
         }
 
         d->delegate->updateItemWidgets(result, option, idx);
 
-        Q_FOREACH (QWidget* const widget, result)
+        for (QWidget* const widget : std::as_const(result))
         {
             widget->move(widget->x() + option.rect.left(), widget->y() + option.rect.top());
         }
@@ -145,8 +145,9 @@ QList<QWidget*> DWItemDelegatePool::findWidgets(const QPersistentModelIndex& idx
 QList<QWidget*> DWItemDelegatePool::invalidIndexesWidgets() const
 {
     QList<QWidget*> result;
+    const auto wdgs = d->widgetInIndex.keys();
 
-    Q_FOREACH (QWidget* const widget, d->widgetInIndex.keys())
+    for (QWidget* const widget : wdgs)
     {
         const QAbstractProxyModel* const proxyModel = qobject_cast<const QAbstractProxyModel*>(d->delegate->d->model);
         QModelIndex index;
@@ -202,7 +203,14 @@ bool DWItemDelegateEventListener::eventFilter(QObject* watched, QEvent* event)
             {
                 QMouseEvent* const mouseEvent = static_cast<QMouseEvent*>(event);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 4, 0))
+
+                QMouseEvent evt(event->type(), viewport->mapFromGlobal(mouseEvent->globalPosition().toPoint()),
+                                mouseEvent->globalPosition().toPoint(), mouseEvent->button(),
+                                mouseEvent->buttons(), mouseEvent->modifiers());
+
+#elif (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
                 QMouseEvent evt(event->type(), viewport->mapFromGlobal(mouseEvent->globalPosition().toPoint()),
                                 mouseEvent->button(), mouseEvent->buttons(), mouseEvent->modifiers());
