@@ -7,7 +7,7 @@
  * Description : setup Metadata tab.
  *
  * SPDX-FileCopyrightText: 2003-2004 by Ralf Holzer <ralf at well dot com>
- * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
  *
@@ -74,6 +74,8 @@ public:
 
 public:
 
+    int                  extensionsMsgBoxResult     = QMessageBox::Help;
+
     bool                 exifAutoRotateOriginal     = false;
     bool                 exifAutoRotateShowedInfo   = false;
     bool                 sidecarFileNameShowedInfo  = false;
@@ -94,6 +96,7 @@ public:
     QCheckBox*           savePosition               = nullptr;
 
     QCheckBox*           useLazySync                = nullptr;
+    QCheckBox*           readWithExifToolBox        = nullptr;
     QCheckBox*           writeWithExifToolBox       = nullptr;
     QCheckBox*           writeDngFilesBox           = nullptr;
     QCheckBox*           writeRawFilesBox           = nullptr;
