@@ -7,7 +7,7 @@
  * Description : digiKam setup dialog.
  *
  * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2003-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -40,12 +40,10 @@
 #include "setuplighttable.h"
 #include "setupmetadata.h"
 #include "setupmisc.h"
-#include "setupimagequalitysorter.h"
 #include "setuptooltip.h"
 #include "setupdatabase.h"
 #include "setupplugins.h"
 #include "importsettings.h"
-#include "dxmlguiwindow.h"
 #include "onlineversiondlg.h"
 
 #ifdef HAVE_GEOLOCATION
@@ -59,91 +57,49 @@ class Q_DECL_HIDDEN Setup::Private
 {
 public:
 
-    explicit Private()
-      : page_database           (nullptr),
-        page_collections        (nullptr),
-        page_albumView          (nullptr),
-        page_tooltip            (nullptr),
-        page_metadata           (nullptr),
-        page_template           (nullptr),
-        page_lighttable         (nullptr),
+    Private() = default;
+
+public:
+
+    DConfigDlgWdgItem*       page_database              = nullptr;
+    DConfigDlgWdgItem*       page_collections           = nullptr;
+    DConfigDlgWdgItem*       page_albumView             = nullptr;
+    DConfigDlgWdgItem*       page_tooltip               = nullptr;
+    DConfigDlgWdgItem*       page_metadata              = nullptr;
+    DConfigDlgWdgItem*       page_template              = nullptr;
+    DConfigDlgWdgItem*       page_lighttable            = nullptr;
 
 #ifdef HAVE_GEOLOCATION
 
-        page_geolocation        (nullptr),
+    DConfigDlgWdgItem*       page_geolocation           = nullptr;
 
 #endif
 
-        page_editor             (nullptr),
-        page_imagequalitysorter (nullptr),
-        page_icc                (nullptr),
-        page_camera             (nullptr),
-        page_plugins            (nullptr),
-        page_misc               (nullptr),
-        databasePage            (nullptr),
-        collectionsPage         (nullptr),
-        albumViewPage           (nullptr),
-        tooltipPage             (nullptr),
-        metadataPage            (nullptr),
-        templatePage            (nullptr),
-        lighttablePage          (nullptr),
+    DConfigDlgWdgItem*       page_editor                = nullptr;
+    DConfigDlgWdgItem*       page_icc                   = nullptr;
+    DConfigDlgWdgItem*       page_camera                = nullptr;
+    DConfigDlgWdgItem*       page_plugins               = nullptr;
+    DConfigDlgWdgItem*       page_misc                  = nullptr;
+
+    SetupDatabase*           databasePage               = nullptr;
+    SetupCollections*        collectionsPage            = nullptr;
+    SetupAlbumView*          albumViewPage              = nullptr;
+    SetupToolTip*            tooltipPage                = nullptr;
+    SetupMetadata*           metadataPage               = nullptr;
+    SetupTemplate*           templatePage               = nullptr;
+    SetupLightTable*         lighttablePage             = nullptr;
 
 #ifdef HAVE_GEOLOCATION
 
-        geolocationPage         (nullptr),
+    SetupGeolocation*        geolocationPage            = nullptr;
 
 #endif
 
-        editorPage              (nullptr),
-        imageQualitySorterPage  (nullptr),
-        iccPage                 (nullptr),
-        cameraPage              (nullptr),
-        pluginsPage             (nullptr),
-        miscPage                (nullptr)
-    {
-    }
-
-    DConfigDlgWdgItem*       page_database;
-    DConfigDlgWdgItem*       page_collections;
-    DConfigDlgWdgItem*       page_albumView;
-    DConfigDlgWdgItem*       page_tooltip;
-    DConfigDlgWdgItem*       page_metadata;
-    DConfigDlgWdgItem*       page_template;
-    DConfigDlgWdgItem*       page_lighttable;
-
-#ifdef HAVE_GEOLOCATION
-
-    DConfigDlgWdgItem*       page_geolocation;
-
-#endif
-
-    DConfigDlgWdgItem*       page_editor;
-    DConfigDlgWdgItem*       page_imagequalitysorter;
-    DConfigDlgWdgItem*       page_icc;
-    DConfigDlgWdgItem*       page_camera;
-    DConfigDlgWdgItem*       page_plugins;
-    DConfigDlgWdgItem*       page_misc;
-
-    SetupDatabase*           databasePage;
-    SetupCollections*        collectionsPage;
-    SetupAlbumView*          albumViewPage;
-    SetupToolTip*            tooltipPage;
-    SetupMetadata*           metadataPage;
-    SetupTemplate*           templatePage;
-    SetupLightTable*         lighttablePage;
-
-#ifdef HAVE_GEOLOCATION
-
-    SetupGeolocation*        geolocationPage;
-
-#endif
-
-    SetupEditor*             editorPage;
-    SetupImageQualitySorter* imageQualitySorterPage;
-    SetupICC*                iccPage;
-    SetupCamera*             cameraPage;
-    SetupPlugins*            pluginsPage;
-    SetupMisc*               miscPage;
+    SetupEditor*             editorPage                 = nullptr;
+    SetupICC*                iccPage                    = nullptr;
+    SetupCamera*             cameraPage                 = nullptr;
+    SetupPlugins*            pluginsPage                = nullptr;
+    SetupMisc*               miscPage                   = nullptr;
 
 public:
 
@@ -157,11 +113,13 @@ Setup::Setup(QWidget* const parent)
     setWindowFlags((windowFlags() & ~Qt::Dialog) |
                    Qt::Window                    |
                    Qt::WindowCloseButtonHint     |
-                   Qt::WindowMinMaxButtonsHint);
+                   Qt::WindowMinMaxButtonsHint   |
+                   Qt::WindowContextHelpButtonHint);
 
     setWindowTitle(i18nc("@title:window", "Configure"));
     setStandardButtons(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     button(QDialogButtonBox::Ok)->setDefault(true);
+    setConfigGroup(QLatin1String("Setup Dialog"));
     setFaceType(List);
     setModal(true);
 
@@ -219,11 +177,6 @@ Setup::Setup(QWidget* const parent)
 
 #endif
 
-    d->imageQualitySorterPage = new SetupImageQualitySorter();
-    d->page_imagequalitysorter = addPage(d->imageQualitySorterPage, i18nc("@title: settings section", "Image Quality Sorter"));
-    d->page_imagequalitysorter->setHeader(i18nc("@title", "Image Quality Sorter Settings\nCustomize default settings to perform image triaging by quality"));
-    d->page_imagequalitysorter->setIcon(QIcon::fromTheme(QLatin1String("flag-green")));
-
     d->cameraPage  = new SetupCamera();
     d->page_camera = addPage(d->cameraPage, i18nc("@title: settings section", "Cameras"));
     d->page_camera->setHeader(i18nc("@title", "Camera Settings\nManage your camera devices"));
@@ -268,14 +221,6 @@ Setup::Setup(QWidget* const parent)
 
     connect(buttonBox()->button(QDialogButtonBox::Cancel), &QPushButton::clicked,
             this, &Setup::slotCancelClicked);
-
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group        = config->group(QLatin1String("Setup Dialog"));
-
-    winId();
-    DXmlGuiWindow::setGoodDefaultWindowSize(windowHandle());
-    DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
-    resize(windowHandle()->size());
 }
 
 Setup::~Setup()
@@ -299,7 +244,6 @@ Setup::~Setup()
     group.writeEntry(QLatin1String("Camera Tab"),      (int)d->cameraPage->activeTab());
     group.writeEntry(QLatin1String("Plugin Tab"),      (int)d->pluginsPage->activeTab());
     group.writeEntry(QLatin1String("Misc Tab"),        (int)d->miscPage->activeTab());
-    DXmlGuiWindow::saveWindowSize(windowHandle(), group);
     config->sync();
 
     delete d;
@@ -381,10 +325,8 @@ bool Setup::execDialog(QWidget* const parent, Page page)
 {
     QPointer<Setup> setup = new Setup(parent);
     setup->showPage(page);
-    bool success          = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
 
-    return success;
+    return openSetup(setup);
 }
 
 bool Setup::execSinglePage(Page page)
@@ -397,10 +339,8 @@ bool Setup::execSinglePage(QWidget* const parent, Page page)
     QPointer<Setup> setup = new Setup(parent);
     setup->showPage(page);
     setup->setFaceType(Plain);
-    bool success          = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
 
-    return success;
+    return openSetup(setup);
 }
 
 bool Setup::execTemplateEditor(QWidget* const parent, const Template& t)
@@ -409,10 +349,8 @@ bool Setup::execTemplateEditor(QWidget* const parent, const Template& t)
     setup->showPage(TemplatePage);
     setup->setFaceType(Plain);
     setup->setTemplate(t);
-    bool success          = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
 
-    return success;
+    return openSetup(setup);
 }
 
 #ifdef HAVE_GEOLOCATION
@@ -439,10 +377,7 @@ bool Setup::execGeolocation(QWidget* const parent, int tab)
 
     widget->setActiveTab((SetupGeolocation::GeolocationTab)tab);
 
-    bool success                   = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
-
-    return success;
+    return openSetup(setup);
 }
 
 #endif
@@ -470,10 +405,7 @@ bool Setup::execMetadataFilters(QWidget* const parent, int tab)
     widget->setActiveTab(SetupMetadata::Display);
     widget->setActiveSubTab((SetupMetadata::MetadataSubTab)tab);
 
-    bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
-
-    return success;
+    return openSetup(setup);
 }
 
 bool Setup::execExifTool(QWidget* const parent)
@@ -498,10 +430,7 @@ bool Setup::execExifTool(QWidget* const parent)
 
     widget->setActiveTab(SetupMetadata::ExifTool);
 
-    bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
-
-    return success;
+    return openSetup(setup);
 }
 
 bool Setup::execLocalize(QWidget* const parent)
@@ -526,33 +455,25 @@ bool Setup::execLocalize(QWidget* const parent)
 
     widget->setActiveTab(SetupMisc::Localize);
 
-    bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
-    delete setup;
-
-    return success;
+    return openSetup(setup);
 }
 
-bool Setup::execImageQualitySorter(QWidget* const parent)
+bool Setup::openSetup(Setup* const setup)
 {
-    QPointer<Setup> setup        = new Setup(parent);
-    setup->showPage(ImageQualityPage);
-    setup->setFaceType(Plain);
+    QEventLoop loop;
+    bool success = false;
 
-    DConfigDlgWdgItem* const cur = setup->currentPage();
+    connect(setup, &QDialog::finished,
+            setup, [&loop, &success](int result)             // clazy:exclude=lambda-in-connect
+            {
+                success = (result == QDialog::Accepted);
+                loop.quit();
+            }
+    );
 
-    if (!cur)
-    {
-        return false;
-    }
+    setup->DConfigDlg::open();
 
-    SetupImageQualitySorter* const widget  = dynamic_cast<SetupImageQualitySorter*>(cur->widget());
-
-    if (!widget)
-    {
-        return false;
-    }
-
-    bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
+    loop.exec();
     delete setup;
 
     return success;
@@ -590,7 +511,6 @@ void Setup::slotOkClicked()
 #endif
 
     d->editorPage->applySettings();
-    d->imageQualitySorterPage->applySettings();
     d->iccPage->applySettings();
     d->pluginsPage->applySettings();
     d->miscPage->applySettings();
@@ -644,7 +564,7 @@ void Setup::showPage(Setup::Page page)
         d->iccPage->setActiveTab((SetupICC::ICCTab)group.readEntry(QLatin1String("ICC Tab"), (int)SetupICC::Behavior));
         d->cameraPage->setActiveTab((SetupCamera::CameraTab)group.readEntry(QLatin1String("Camera Tab"), (int)SetupCamera::Devices));
         d->pluginsPage->setActiveTab((SetupPlugins::PluginTab)group.readEntry(QLatin1String("Plugin Tab"), (int)SetupPlugins::Generic));
-        d->miscPage->setActiveTab((SetupMisc::MiscTab)group.readEntry(QLatin1String("Misc Tab"), (int)SetupMisc::Behaviour));
+        d->miscPage->setActiveTab((SetupMisc::MiscTab)group.readEntry(QLatin1String("Misc Tab"), (int)SetupMisc::Behavior));
     }
     else
     {
@@ -707,11 +627,6 @@ Setup::Page Setup::activePageIndex() const
         return EditorPage;
     }
 
-    if (cur == d->page_imagequalitysorter)
-    {
-        return ImageQualityPage;
-    }
-
     if (cur == d->page_icc)
     {
         return ICCPage;
@@ -788,11 +703,6 @@ DConfigDlgWdgItem* Setup::Private::pageItem(Setup::Page page) const
             return page_editor;
         }
 
-        case Setup::ImageQualityPage:
-        {
-            return page_imagequalitysorter;
-        }
-
         case Setup::ICCPage:
         {
             return page_icc;
